/*
Rolling shutter absolute camera pose with known vertical direction solver

int r5p(Scalar g[3], Scalar X[3 * 5], Scalar u[2 * 5], Scalar c0, int direction, Scalar(&C)[60], Scalar(&t)[60], Scalar(&R)[180], Scalar(&w)[60])

input	
g - 3x1 vector pointing down in the direction of gravitational force with respect to the camera frame
X - 5x3 matrix of 3D points (X == [x y z]')
u - 5x2 matrix of corresponding 2D image points (u == [r c]')
r0 - rolling shutter setpoint, linearization point of the model, default 0 - center of the image
direction - the image axis along which the lines are being read out, 0 - horizontal, 1 - vertical 

output	parameters of the camera projecting the 3D point as

[r c 1]' = (I+X_((r-r0)*w))*Rv*Ry(q)*X+C+(r-r0)*t);

R - is the complete matrix Rv*Ry(q)=R

where X_(a) produces a shew symmetric matrix such that X_(a)*a= [0 0 0]'

Please, refer to the following paper:

Cenek Albl, Zuzana Kukelova, Tomas Pajdla;
Rolling Shutter Absolute Pose Problem With Known Vertical Direction
The IEEE Conference on Computer Vision and Pattern Recognition (CVPR),
2016, pp. 3355-3363

Copyright (c) 2016, Cenek Albl <alblcene@cmp.felk.cvut.cz> and Zuzana Kukelova <zukuke@microsoft.com>
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
* Neither the names of the Czech Technical University and Microsoft nor the
names of its contributors may be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef _R5PUP_H_
#define _R5PUP_H_

#include <eigen3/Eigen/Dense>
#include <eigen3/Eigen/Sparse>
#include <list>
#include <iostream>


#include "gj.h"


template <typename Scalar>

int r5p(Scalar g[3], Scalar X[3 * 5], Scalar u[2 * 5], Scalar c0, int direction, Scalar(&C)[60], Scalar(&t)[60], Scalar(&R)[180], Scalar(&w)[60]){
	Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> M(15, 18);
	M.setZero();
	int idx, ii;
	double r0 = 0;
	Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> Rv;
	Eigen::Matrix<Scalar, 3, 1> upvec, down;
	down << 0, 1, 0;
	upvec << g[0], g[1], g[2];

	Eigen::Matrix<Scalar, 3, 1> ax = upvec.cross(down);
	ax /= ax.norm();
	double angle = acos(upvec.dot(down) / upvec.norm());
	Eigen::Matrix<Scalar, 3, 3> skewAx;
	skewAx << 0, -ax[2], ax[1],
		ax[2], 0, -ax[0],
		ax[1], ax[0], 0;
	Rv = Eigen::Matrix<Scalar, 3, 3>::Identity()*cos(angle) + sin(angle)*skewAx + (1 - cos(angle))*ax*ax.transpose();
	Rv.transposeInPlace();

	if (direction){
		for (idx = 0; idx < 5; idx++) {
			ii = 3 * (1 + idx) - 3;
			M.data()[ii] = 0.0;
			M.data()[15 + ii] = -1.0;
			M.data()[30 + ii] = u[1 + (idx << 1)];
			M.data()[45 + ii] = 0.0;
			M.data()[60 + ii] = r0 - u[1 + (idx << 1)];
			M.data()[75 + ii] = u[1 + (idx << 1)] * (u[1 + (idx << 1)] - r0);
			M.data()[90 + ii] = ((X[1 + 3 * idx] * Rv.data()[5] * (u[1 + (idx << 1)] - r0) - X[3 * idx]
				* Rv.data()[2] * (u[1 + (idx << 1)] - r0)) - u[1 + (idx << 1)] * ((X
				[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx] * Rv.data()[4] * (u[1
				+ (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7] * (u[1 + (idx << 1)] - r0)))
				- X[2 + 3 * idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0);
			M.data()[105 + ii] = (u[1 + (idx << 1)] * (2.0 * X[3 * idx] * Rv.data()[7] * (u[1 + (idx <<
				1)] - r0) - 2.0 * X[2 + 3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0)) + 2.0 *
				X[3 * idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0)) - 2.0 * X[2 + 3
				* idx] * Rv.data()[2] * (u[1 + (idx << 1)] - r0);
			M.data()[120 + ii] = ((u[1 + (idx << 1)] * ((X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)]
				- r0) + X[1 + 3 * idx] * Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx]
				* Rv.data()[7] * (u[1 + (idx << 1)] - r0)) + X[3 * idx] * Rv.data()[2] * (u[1 + (idx << 1)]
				- r0)) + X[1 + 3 * idx] * Rv.data()[5] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx]
				* Rv.data()[8] * (u[1 + (idx << 1)] - r0);
			M.data()[135 + ii] = u[1 + (idx << 1)] * ((X[3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] -
				r0) - X[1 + 3 * idx] * Rv.data()[3] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] *
				Rv.data()[6] * (u[1 + (idx << 1)] - r0));
			M.data()[150 + ii] = -u[1 + (idx << 1)] * (2.0 * X[3 * idx] * Rv.data()[6] * (u[1 + (idx <<
				1)] - r0) - 2.0 * X[2 + 3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0));
			M.data()[165 + ii] = -u[1 + (idx << 1)] * ((X[3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)]
				- r0) + X[1 + 3 * idx] * Rv.data()[3] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx]
				* Rv.data()[6] * (u[1 + (idx << 1)] - r0));
			M.data()[180 + ii] = (X[3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx]
				* Rv.data()[3] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[6] *
				(u[1 + (idx << 1)] - r0);
			M.data()[195 + ii] = 2.0 * X[2 + 3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0) - 2.0 *
				X[3 * idx] * Rv.data()[6] * (u[1 + (idx << 1)] - r0);
			M.data()[210 + ii] = (-X[3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx]
				* Rv.data()[3] * (u[1 + (idx << 1)] - r0)) - X[2 + 3 * idx] * Rv.data()[6] *
				(u[1 + (idx << 1)] - r0);
			M.data()[225 + ii] = ((X[3 * idx] * Rv.data()[1] - X[1 + 3 * idx] * Rv.data()[4]) + X[2 + 3 * idx] *
				Rv.data()[7]) - u[1 + (idx << 1)] * ((X[3 * idx] * Rv.data()[2] - X[1 + 3 *
				idx] * Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()[8]);
			M.data()[240 + ii] = (2.0 * X[2 + 3 * idx] * Rv.data()[1] - 2.0 * X[3 * idx] * Rv.data()[7]) + u[1
				+ (idx << 1)] * (2.0 * X[3 * idx] * Rv.data()[8] - 2.0 * X[2 + 3 * idx] * Rv.data()[2]);
			M.data()[255 + ii] = ((u[1 + (idx << 1)] * ((X[3 * idx] * Rv.data()[2] + X[1 + 3 * idx] *
				Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()[8]) - X[1 + 3 * idx] * Rv.data()[4]) - X[2 + 3 * idx] *
				Rv.data()[7]) - X[3 * idx] * Rv.data()[1];
			ii = 3 * (1 + idx) - 2;
			M.data()[ii] = 1.0;
			M.data()[15 + ii] = 0.0;
			M.data()[30 + ii] = -u[idx << 1];
			M.data()[45 + ii] = u[1 + (idx << 1)] - r0;
			M.data()[60 + ii] = 0.0;
			M.data()[75 + ii] = -u[idx << 1] * (u[1 + (idx << 1)] - r0);
			M.data()[90 + ii] = u[idx << 1] * ((X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) -
				X[1 + 3 * idx] * Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7] *
				(u[1 + (idx << 1)] - r0));
			M.data()[105 + ii] = -u[idx << 1] * (2.0 * X[3 * idx] * Rv.data()[7] * (u[1 + (idx << 1)] -
				r0) - 2.0 * X[2 + 3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0));
			M.data()[120 + ii] = -u[idx << 1] * ((X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0)
				+ X[1 + 3 * idx] * Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7]
				* (u[1 + (idx << 1)] - r0));
			M.data()[135 + ii] = ((X[1 + 3 * idx] * Rv.data()[5] * (u[1 + (idx << 1)] - r0) - X[3 * idx]
				* Rv.data()[2] * (u[1 + (idx << 1)] - r0)) - u[idx << 1] * ((X[3 *
				idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx] * Rv.data()[3] * (u[1 +
				(idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[6] * (u[1 + (idx << 1)] - r0))) -
				X[2 + 3 * idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0);
			M.data()[150 + ii] = (u[idx << 1] * (2.0 * X[3 * idx] * Rv.data()[6] * (u[1 + (idx << 1)] -
				r0) - 2.0 * X[2 + 3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0)) + 2.0 * X[3 *
				idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0)) - 2.0 * X[2 + 3 * idx]
				* Rv.data()[2] * (u[1 + (idx << 1)] - r0);
			M.data()[165 + ii] = ((u[idx << 1] * ((X[3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0)
				+ X[1 + 3 * idx] * Rv.data()[3] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[6]
				* (u[1 + (idx << 1)] - r0)) + X[3 * idx] * Rv.data()[2] * (u[1 + (idx << 1)] - r0))
				+ X[1 + 3 * idx] * Rv.data()[5] * (u[1 + (idx << 1)] - r0)) + X[2 + 3
				* idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0);
			M.data()[180 + ii] = (X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx]
				* Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7] *
				(u[1 + (idx << 1)] - r0);
			M.data()[195 + ii] = 2.0 * X[2 + 3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - 2.0 *
				X[3 * idx] * Rv.data()[7] * (u[1 + (idx << 1)] - r0);
			M.data()[210 + ii] = (-X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx]
				* Rv.data()[4] * (u[1 + (idx << 1)] - r0)) - X[2 + 3 * idx] * Rv.data()[7] *
				(u[1 + (idx << 1)] - r0);
			M.data()[225 + ii] = ((X[1 + 3 * idx] * Rv.data()[3] - X[3 * idx] * Rv.data()[0]) - X[2 + 3 * idx] *
				Rv.data()[6]) + u[idx << 1] * ((X[3 * idx] * Rv.data()[2] - X[1 + 3 * idx] *
				Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()[8]);
			M.data()[240 + ii] = (2.0 * X[3 * idx] * Rv.data()[6] - 2.0 * X[2 + 3 * idx] * Rv.data()[0]) -
				u[idx << 1] * (2.0 * X[3 * idx] * Rv.data()[8] - 2.0 * X[2 + 3 * idx] * Rv.data()[2]);
			M.data()[255 + ii] = ((X[3 * idx] * Rv.data()[0] + X[1 + 3 * idx] * Rv.data()[3]) + X[2 + 3 * idx] *
				Rv.data()[6]) - u[idx << 1] * ((X[3 * idx] * Rv.data()[2] + X[1 + 3 * idx] *
				Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()[8]);
			ii = 3 * (1 + idx) - 1;
			M.data()[ii] = 1.0;
			M.data()[15 + ii] = 0.0;
			M.data()[30 + ii] = -u[idx << 1];
			M.data()[45 + ii] = u[1 + (idx << 1)] - r0;
			M.data()[60 + ii] = 0.0;
			M.data()[75 + ii] = -u[idx << 1] * (u[1 + (idx << 1)] - r0);
			M.data()[90 + ii] = u[idx << 1] * ((X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) -
				X[1 + 3 * idx] * Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7] *
				(u[1 + (idx << 1)] - r0));
			M.data()[105 + ii] = -u[idx << 1] * (2.0 * X[3 * idx] * Rv.data()[7] * (u[1 + (idx << 1)] -
				r0) - 2.0 * X[2 + 3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0));
			M.data()[120 + ii] = -u[idx << 1] * ((X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0)
				+ X[1 + 3 * idx] * Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7]
				* (u[1 + (idx << 1)] - r0));
			M.data()[135 + ii] = ((X[1 + 3 * idx] * Rv.data()[5] * (u[1 + (idx << 1)] - r0) - X[3 * idx]
				* Rv.data()[2] * (u[1 + (idx << 1)] - r0)) - u[idx << 1] * ((X[3 *
				idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx] * Rv.data()[3] * (u[1 +
				(idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[6] * (u[1 + (idx << 1)] - r0))) -
				X[2 + 3 * idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0);
			M.data()[150 + ii] = (u[idx << 1] * (2.0 * X[3 * idx] * Rv.data()[6] * (u[1 + (idx << 1)] -
				r0) - 2.0 * X[2 + 3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0)) + 2.0 * X[3 *
				idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0)) - 2.0 * X[2 + 3 * idx]
				* Rv.data()[2] * (u[1 + (idx << 1)] - r0);
			M.data()[165 + ii] = ((u[idx << 1] * ((X[3 * idx] * Rv.data()[0] * (u[1 + (idx << 1)] - r0)
				+ X[1 + 3 * idx] * Rv.data()[3] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[6]
				* (u[1 + (idx << 1)] - r0)) + X[3 * idx] * Rv.data()[2] * (u[1 + (idx << 1)] - r0))
				+ X[1 + 3 * idx] * Rv.data()[5] * (u[1 + (idx << 1)] - r0)) + X[2 + 3
				* idx] * Rv.data()[8] * (u[1 + (idx << 1)] - r0);
			M.data()[180 + ii] = (X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx]
				* Rv.data()[4] * (u[1 + (idx << 1)] - r0)) + X[2 + 3 * idx] * Rv.data()[7] *
				(u[1 + (idx << 1)] - r0);
			M.data()[195 + ii] = 2.0 * X[2 + 3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - 2.0 *
				X[3 * idx] * Rv.data()[7] * (u[1 + (idx << 1)] - r0);
			M.data()[210 + ii] = (-X[3 * idx] * Rv.data()[1] * (u[1 + (idx << 1)] - r0) - X[1 + 3 * idx]
				* Rv.data()[4] * (u[1 + (idx << 1)] - r0)) - X[2 + 3 * idx] * Rv.data()[7] *
				(u[1 + (idx << 1)] - r0);
			M.data()[225 + ii] = ((X[1 + 3 * idx] * Rv.data()[3] - X[3 * idx] * Rv.data()[0]) - X[2 + 3 * idx] *
				Rv.data()[6]) + u[idx << 1] * ((X[3 * idx] * Rv.data()[2] - X[1 + 3 * idx] *
				Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()[8]);
			M.data()[240 + ii] = (2.0 * X[3 * idx] * Rv.data()[6] - 2.0 * X[2 + 3 * idx] * Rv.data()[0]) -
				u[idx << 1] * (2.0 * X[3 * idx] * Rv.data()[8] - 2.0 * X[2 + 3 * idx] * Rv.data()[2]);
			M.data()[255 + ii] = ((X[3 * idx] * Rv.data()[0] + X[1 + 3 * idx] * Rv.data()[3]) + X[2 + 3 * idx] *
				Rv.data()[6]) - u[idx << 1] * ((X[3 * idx] * Rv.data()[2] + X[1 + 3 * idx] *
				Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()[8]);
		}
	}
	else{
		for (idx = 0; idx < 5; idx++) {
			ii = 3 * (1 + idx) - 3;
			M.data()[ii] = 0.0;
			M.data()[15 + ii] = -1.0;
			M.data()[30 + ii] = u[1 + (idx << 1)];
			M.data()[45 + ii] = 0.0;
			M.data()[60 + ii] = r0 - u[idx << 1];
			M.data()[75 + ii] = u[1 + (idx << 1)] * (u[idx << 1] - r0);
			M.data()[90 + ii] = ((X[1 + 3 *idx] * Rv.data()[5] * (u[idx << 1] - r0) - X[3 *idx] * Rv.data()[2] *
				(u[idx << 1] - r0)) - u[1 + (idx << 1)] * ((X[3 *idx] * Rv.data()[1] *
				(u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[4] * (u[idx << 1] - r0)) + X[2 + 3 *idx] *
				Rv.data()[7] * (u[idx << 1] - r0))) - X[2 + 3 *idx] * Rv.data()[8] * (u[idx << 1] - r0);
			M.data()[105 + ii] = (u[1 + (idx << 1)] * (2.0 * X[3 *idx] * Rv.data()[7] * (u[idx << 1] - r0) -
				2.0 * X[2 + 3 *idx] * Rv.data()[1] * (u[idx << 1] - r0)) + 2.0 * X[3 *idx] * Rv.data()[8] *
				(u[idx << 1] - r0)) - 2.0 * X[2 + 3 *idx] * Rv.data()[2] * (u[idx << 1] -
				r0);
			M.data()[120 + ii] = ((u[1 + (idx << 1)] * ((X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) + X[1
				+ 3 *idx] * Rv.data()[4] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] -
				r0)) + X[3 *idx] * Rv.data()[2] * (u[idx << 1] - r0)) + X[1 + 3 *idx] * Rv.data()[5] * (u[idx <<
				1] - r0)) + X[2 + 3 *idx] * Rv.data()[8] * (u[idx << 1] - r0);
			M.data()[135 + ii] = u[1 + (idx << 1)] * ((X[3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) - X[1 +
				3 *idx] * Rv.data()[3] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[6] * (u[idx << 1] - r0));
			M.data()[150 + ii] = -u[1 + (idx << 1)] * (2.0 * X[3 *idx] * Rv.data()[6] * (u[idx << 1] - r0) -
				2.0 * X[2 + 3 *idx] * Rv.data()[0] * (u[idx << 1] - r0));
			M.data()[165 + ii] = -u[1 + (idx << 1)] * ((X[3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) + X[1
				+ 3 *idx] * Rv.data()[3] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[6] * (u[idx << 1] -
				r0));
			M.data()[180 + ii] = (X[3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[3] *
				(u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[6] * (u[idx << 1] - r0);
			M.data()[195 + ii] = 2.0 * X[2 + 3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) - 2.0 * X[3 *idx] *
				Rv.data()[6] * (u[idx << 1] - r0);
			M.data()[210 + ii] = (-X[3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[3] *
				(u[idx << 1] - r0)) - X[2 + 3 *idx] * Rv.data()[6] * (u[idx << 1] - r0);
			M.data()[225 + ii] = ((X[3 *idx] * Rv.data()[1] - X[1 + 3 *idx] * Rv.data()[4]) + X[2 + 3 *idx] * Rv.data()[7])
				- u[1 + (idx << 1)] * ((X[3 *idx] * Rv.data()[2] - X[1 + 3 *idx] * Rv.data()[5]) + X[2 + 3 *idx]
				* Rv.data()[8]);
			M.data()[240 + ii] = (2.0 * X[2 + 3 *idx] * Rv.data()[1] - 2.0 * X[3 *idx] * Rv.data()[7]) + u[1 + (idx
				<< 1)] * (2.0 * X[3 *idx] * Rv.data()[8] - 2.0 * X[2 + 3 *idx] * Rv.data()[2]);
			M.data()[255 + ii] = ((u[1 + (idx << 1)] * ((X[3 *idx] * Rv.data()[2] + X[1 + 3 *idx] * Rv.data()[5]) +
				X[2 + 3 *idx] * Rv.data()[8]) - X[1 + 3 *idx] * Rv.data()[4]) - X[2 + 3 *idx] * Rv.data()[7]) - X[3 *
				idx] * Rv.data()[1];
			ii = 3 * (1 + idx) - 2;
			M.data()[ii] = 1.0;
			M.data()[15 + ii] = 0.0;
			M.data()[30 + ii] = -u[idx << 1];
			M.data()[45 + ii] = u[idx << 1] - r0;
			M.data()[60 + ii] = 0.0;
			M.data()[75 + ii] = -u[idx << 1] * (u[idx << 1] - r0);
			M.data()[90 + ii] = u[idx << 1] * ((X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - X[1 + 3 *idx]
				* Rv.data()[4] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] - r0));
			M.data()[105 + ii] = -u[idx << 1] * (2.0 * X[3 *idx] * Rv.data()[7] * (u[idx << 1] - r0) - 2.0 *
				X[2 + 3 *idx] * Rv.data()[1] * (u[idx << 1] - r0));
			M.data()[120 + ii] = -u[idx << 1] * ((X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) + X[1 + 3 *
				idx] * Rv.data()[4] * (u[idx << 1] - r0)) + X[2 + 3 * idx] * Rv.data()[7] * (u[idx << 1] - r0));
			M.data()[135 + ii] = ((X[1 + 3 *idx] * Rv.data()[5] * (u[idx << 1] - r0) - X[3 *idx] * Rv.data()[2] *
				(u[idx << 1] - r0)) - u[idx << 1] * ((X[3 *idx] * Rv.data()[0] * (u[idx <<
				1] - r0) - X[1 + 3 *idx] * Rv.data()[3] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[6] *
				(u[idx << 1] - r0))) - X[2 + 3 *idx] * Rv.data()[8] * (u[idx << 1] - r0);
			M.data()[150 + ii] = (u[idx << 1] * (2.0 * X[3 *idx] * Rv.data()[6] * (u[idx << 1] - r0) - 2.0 *
				X[2 + 3 *idx] * Rv.data()[0] * (u[idx << 1] - r0)) + 2.0 * X[3 *idx] * Rv.data()[8] * (u[idx <<
				1] - r0)) - 2.0 * X[2 + 3 *idx] * Rv.data()[2] * (u[idx << 1] - r0);
			M.data()[165 + ii] = ((u[idx << 1] * ((X[3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) + X[1 + 3 *
				idx] * Rv.data()[3] * (u[idx << 1] - r0)) + X[2 + 3 * idx] * Rv.data()[6] * (u[idx << 1] - r0)) +
				X[3 *idx] * Rv.data()[2] * (u[idx << 1] - r0)) + X[1 + 3 *idx] * Rv.data()[5] *
				(u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[8] * (u[idx << 1] - r0);
			M.data()[180 + ii] = (X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[4] *
				(u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] - r0);
			M.data()[195 + ii] = 2.0 * X[2 + 3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - 2.0 * X[3 *idx] *
				Rv.data()[7] * (u[idx << 1] - r0);
			M.data()[210 + ii] = (-X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[4] *
				(u[idx << 1] - r0)) - X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] - r0);
			M.data()[225 + ii] = ((X[1 + 3 *idx] * Rv.data()[3] - X[3 *idx] * Rv.data()[0]) - X[2 + 3 *idx] * Rv.data()[6])
				+ u[idx << 1] * ((X[3 * idx] * Rv.data()[2] - X[1 + 3 * idx] * Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()
				[8]);
			M.data()[240 + ii] = (2.0 * X[3 *idx] * Rv.data()[6] - 2.0 * X[2 + 3 *idx] * Rv.data()[0]) - u[idx << 1]
				* (2.0 * X[3 *idx] * Rv.data()[8] - 2.0 * X[2 + 3 *idx] * Rv.data()[2]);
			M.data()[255 + ii] = ((X[3 *idx] * Rv.data()[0] + X[1 + 3 *idx] * Rv.data()[3]) + X[2 + 3 *idx] * Rv.data()[6])
				- u[idx << 1] * ((X[3 * idx] * Rv.data()[2] + X[1 + 3 * idx] * Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()
				[8]);
			ii = 3 * (1 + idx) - 1;
			M.data()[ii] = 1.0;
			M.data()[15 + ii] = 0.0;
			M.data()[30 + ii] = -u[idx << 1];
			M.data()[45 + ii] = u[idx << 1] - r0;
			M.data()[60 + ii] = 0.0;
			M.data()[75 + ii] = -u[idx << 1] * (u[idx << 1] - r0);
			M.data()[90 + ii] = u[idx << 1] * ((X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - X[1 + 3 *idx]
				* Rv.data()[4] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] - r0));
			M.data()[105 + ii] = -u[idx << 1] * (2.0 * X[3 *idx] * Rv.data()[7] * (u[idx << 1] - r0) - 2.0 *
				X[2 + 3 *idx] * Rv.data()[1] * (u[idx << 1] - r0));
			M.data()[120 + ii] = -u[idx << 1] * ((X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) + X[1 + 3 *
				idx] * Rv.data()[4] * (u[idx << 1] - r0)) + X[2 + 3 * idx] * Rv.data()[7] * (u[idx << 1] - r0));
			M.data()[135 + ii] = ((X[1 + 3 *idx] * Rv.data()[5] * (u[idx << 1] - r0) - X[3 *idx] * Rv.data()[2] *
				(u[idx << 1] - r0)) - u[idx << 1] * ((X[3 *idx] * Rv.data()[0] * (u[idx <<
				1] - r0) - X[1 + 3 *idx] * Rv.data()[3] * (u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[6] *
				(u[idx << 1] - r0))) - X[2 + 3 *idx] * Rv.data()[8] * (u[idx << 1] - r0);
			M.data()[150 + ii] = (u[idx << 1] * (2.0 * X[3 *idx] * Rv.data()[6] * (u[idx << 1] - r0) - 2.0 *
				X[2 + 3 *idx] * Rv.data()[0] * (u[idx << 1] - r0)) + 2.0 * X[3 *idx] * Rv.data()[8] * (u[idx <<
				1] - r0)) - 2.0 * X[2 + 3 *idx] * Rv.data()[2] * (u[idx << 1] - r0);
			M.data()[165 + ii] = ((u[idx << 1] * ((X[3 *idx] * Rv.data()[0] * (u[idx << 1] - r0) + X[1 + 3 *
				idx] * Rv.data()[3] * (u[idx << 1] - r0)) + X[2 + 3 * idx] * Rv.data()[6] * (u[idx << 1] - r0)) +
				X[3 *idx] * Rv.data()[2] * (u[idx << 1] - r0)) + X[1 + 3 *idx] * Rv.data()[5] *
				(u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[8] * (u[idx << 1] - r0);
			M.data()[180 + ii] = (X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[4] *
				(u[idx << 1] - r0)) + X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] - r0);
			M.data()[195 + ii] = 2.0 * X[2 + 3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - 2.0 * X[3 *idx] *
				Rv.data()[7] * (u[idx << 1] - r0);
			M.data()[210 + ii] = (-X[3 *idx] * Rv.data()[1] * (u[idx << 1] - r0) - X[1 + 3 *idx] * Rv.data()[4] *
				(u[idx << 1] - r0)) - X[2 + 3 *idx] * Rv.data()[7] * (u[idx << 1] - r0);
			M.data()[225 + ii] = ((X[1 + 3 *idx] * Rv.data()[3] - X[3 *idx] * Rv.data()[0]) - X[2 + 3 *idx] * Rv.data()[6])
				+ u[idx << 1] * ((X[3 * idx] * Rv.data()[2] - X[1 + 3 * idx] * Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()
				[8]);
			M.data()[240 + ii] = (2.0 * X[3 *idx] * Rv.data()[6] - 2.0 * X[2 + 3 *idx] * Rv.data()[0]) - u[idx << 1]
				* (2.0 * X[3 *idx] * Rv.data()[8] - 2.0 * X[2 + 3 *idx] * Rv.data()[2]);
			M.data()[255 + ii] = ((X[3 *idx] * Rv.data()[0] + X[1 + 3 *idx] * Rv.data()[3]) + X[2 + 3 *idx] * Rv.data()[6])
				- u[idx << 1] * ((X[3 * idx] * Rv.data()[2] + X[1 + 3 * idx] * Rv.data()[5]) + X[2 + 3 * idx] * Rv.data()
				[8]);

		}
	}
	Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> Mr(15, 18);

	Mr.setZero();

	//std::cout << M.row(0);

	gj_row_wise(M.data(), Mr.data(), 15, 18, 1e-9);

	//std::cout << Mr.row(0);

	Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> M2 = Mr.block(6, 6, 4, 12);

	Eigen::Matrix<Scalar, 9, 1> cq;

	cq[0] = ((((((((((((((((((((((Mr.data()[97] * Mr.data()[188] * Mr.data()[144] * Mr.data()[231] - Mr.data()[97] * Mr.data()[143]
		* Mr.data()[189] * Mr.data()[231]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[142] * Mr.data()[188] *
		Mr.data()[99] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[98] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[143] * Mr.data()[99]
		* Mr.data()[231]) + Mr.data()[96] * Mr.data()[143] * Mr.data()[189] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[188] * Mr.data()[144] * Mr.data()
		[232]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[189] * Mr.data()[232]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[99] * Mr.data()[232])
		+ Mr.data()[186] * Mr.data()[98] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[143] *
		Mr.data()[99] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[142] * Mr.data()[189] * Mr.data()[233]) + Mr.data()[96]
		* Mr.data()[187] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[189] * Mr.data()
		[233]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[99] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[97] *
		Mr.data()[144] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[142] * Mr.data()[99] * Mr.data()[233]) + Mr.data()[96] *
		Mr.data()[142] * Mr.data()[188] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[187] * Mr.data()[143] * Mr.data()[234]) -
		Mr.data()[141] * Mr.data()[97] * Mr.data()[188] * Mr.data()[234]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[98] * Mr.data()[234])
		+ Mr.data()[186] * Mr.data()[97] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[142] * Mr.data()[98] * Mr.data()[234];
	cq[1] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((Mr.data()[97] * Mr.data()[188] * Mr.data()[144] * Mr.data()[246] - Mr.data()[97] * Mr.data()[143] * Mr.data()[204] *
		Mr.data()[231]) - Mr.data()[97] * Mr.data()[158] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[97] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[246]) + Mr.data()[97] * Mr.data()[188] * Mr.data()[159] * Mr.data()[231]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[144] * Mr.data()[231])
		- Mr.data()[112] * Mr.data()[143] * Mr.data()[189] * Mr.data()[231]) + Mr.data()[112] * Mr.data()[188] * Mr.data()[144] * Mr.data()[231]) +
		Mr.data()[142] * Mr.data()[98] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[204] * Mr.data()[231]) + Mr.data()
		[142] * Mr.data()[113] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[99] * Mr.data()[246]) - Mr.data()
		[142] * Mr.data()[188] * Mr.data()[114] * Mr.data()[231]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[99] * Mr.data()[231]) + Mr.data()
		[157] * Mr.data()[98] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[157] * Mr.data()[188] * Mr.data()[99] * Mr.data()[231]) - Mr.data()[187]
		* Mr.data()[98] * Mr.data()[144] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[98] * Mr.data()[159] * Mr.data()[231]) - Mr.data()[187] * Mr.data()
		[113] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[143] * Mr.data()[99] * Mr.data()[246]) + Mr.data()[187] * Mr.data()
		[143] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[158] * Mr.data()[99] * Mr.data()[231]) - Mr.data()[202] * Mr.data()[98]
		* Mr.data()[144] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[99] * Mr.data()[231]) + Mr.data()[96] * Mr.data()[143] * Mr.data()
		[189] * Mr.data()[247]) + Mr.data()[96] * Mr.data()[143] * Mr.data()[204] * Mr.data()[232]) + Mr.data()[96] * Mr.data()[158] * Mr.data()[189]
		* Mr.data()[232]) - Mr.data()[96] * Mr.data()[188] * Mr.data()[144] * Mr.data()[247]) - Mr.data()[96] * Mr.data()[188] * Mr.data()[159] * Mr.data()
		[232]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[144] * Mr.data()[232]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[232]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[189] * Mr.data()
		[247]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[204] * Mr.data()[232]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[189] * Mr.data()
		[232]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[99] * Mr.data()[247]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[114] * Mr.data()
		[232]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[99] * Mr.data()[232]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[189] * Mr.data()[232])
		+ Mr.data()[156] * Mr.data()[188] * Mr.data()[99] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[98] * Mr.data()[144] * Mr.data()[247]) + Mr.data()
		[186] * Mr.data()[98] * Mr.data()[159] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[113] * Mr.data()[144] * Mr.data()[232]) - Mr.data()
		[186] * Mr.data()[143] * Mr.data()[99] * Mr.data()[247]) - Mr.data()[186] * Mr.data()[143] * Mr.data()[114] * Mr.data()[232]) - Mr.data()
		[186] * Mr.data()[158] * Mr.data()[99] * Mr.data()[232]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[201]
		* Mr.data()[143] * Mr.data()[99] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[142] * Mr.data()[189] * Mr.data()[248]) - Mr.data()[96] * Mr.data()
		[142] * Mr.data()[204] * Mr.data()[233]) - Mr.data()[96] * Mr.data()[157] * Mr.data()[189] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[187]
		* Mr.data()[144] * Mr.data()[248]) + Mr.data()[96] * Mr.data()[187] * Mr.data()[159] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[202] * Mr.data()
		[144] * Mr.data()[233]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[189] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[187] * Mr.data()
		[144] * Mr.data()[233]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[204]
		* Mr.data()[233]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[99] *
		Mr.data()[248]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[114] * Mr.data()[233]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[99] * Mr.data()
		[233]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[156] * Mr.data()[187] * Mr.data()[99] * Mr.data()[233])
		- Mr.data()[186] * Mr.data()[97] * Mr.data()[144] * Mr.data()[248]) - Mr.data()[186] * Mr.data()[97] * Mr.data()[159] * Mr.data()[233]) - Mr.data()
		[186] * Mr.data()[112] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[142] * Mr.data()[99] * Mr.data()[248]) + Mr.data()
		[186] * Mr.data()[142] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[157] * Mr.data()[99] * Mr.data()[233]) - Mr.data()
		[201] * Mr.data()[97] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[99] * Mr.data()[233]) + Mr.data()[96]
		* Mr.data()[142] * Mr.data()[188] * Mr.data()[249]) + Mr.data()[96] * Mr.data()[142] * Mr.data()[203] * Mr.data()[234]) + Mr.data()[96] * Mr.data()
		[157] * Mr.data()[188] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[187] * Mr.data()[143] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[187]
		* Mr.data()[158] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[143] * Mr.data()[234]) +
		Mr.data()[111] * Mr.data()[142] * Mr.data()[188] * Mr.data()[234]) - Mr.data()[111] * Mr.data()[187] * Mr.data()
		[143] * Mr.data()[234]) - Mr.data()[141] * Mr.data()[97] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[141]
		* Mr.data()[97] * Mr.data()[203] * Mr.data()[234]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[188] * Mr.data()[234])
		+ Mr.data()[141] * Mr.data()[187] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[113] *
		Mr.data()[234]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[98] * Mr.data()[234]) - Mr.data()[156] * Mr.data()[97] * Mr.data()
		[188] * Mr.data()[234]) + Mr.data()[156] * Mr.data()[187] * Mr.data()[98] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[97]
		* Mr.data()[143] * Mr.data()[249]) + Mr.data()[186] * Mr.data()[97] * Mr.data()[158] * Mr.data()[234]) + Mr.data()[186] * Mr.data()
		[112] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[142] * Mr.data()[98] * Mr.data()[249]) - Mr.data()[186] *
		Mr.data()[142] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[98] * Mr.data()[234]) + Mr.data()[201] *
		Mr.data()[97] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[201] * Mr.data()[142] * Mr.data()[98] * Mr.data()[234];
	cq[2] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((Mr.data()[97] * Mr.data()[188] * Mr.data()[144] * Mr.data()[261] - Mr.data()[97] * Mr.data()[143] * Mr.data()[204] * Mr.data()[246])
		- Mr.data()[97] * Mr.data()[143] * Mr.data()[219] * Mr.data()[231]) - Mr.data()[97] * Mr.data()[158] * Mr.data()[189] * Mr.data()[246]) - Mr.data()
		[97] * Mr.data()[158] * Mr.data()[204] * Mr.data()[231]) - Mr.data()[97] * Mr.data()[173] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[97]
		* Mr.data()[143] * Mr.data()[189] * Mr.data()[261]) + Mr.data()[97] * Mr.data()[188] * Mr.data()[159] * Mr.data()[246]) + Mr.data()[97] * Mr.data()
		[188] * Mr.data()[174] * Mr.data()[231]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[144] * Mr.data()[246]) + Mr.data()[97] * Mr.data()[203]
		* Mr.data()[159] * Mr.data()[231]) + Mr.data()[97] * Mr.data()[218] * Mr.data()[144] * Mr.data()[231]) - Mr.data()[112] * Mr.data()[143] *
		Mr.data()[189] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[143] * Mr.data()[204] * Mr.data()[231]) - Mr.data()[112] * Mr.data()[158] * Mr.data()
		[189] * Mr.data()[231]) + Mr.data()[112] * Mr.data()[188] * Mr.data()[144] * Mr.data()[246]) + Mr.data()[112] * Mr.data()[188] * Mr.data()
		[159] * Mr.data()[231]) + Mr.data()[112] * Mr.data()[203] * Mr.data()[144] * Mr.data()[231]) - Mr.data()[127] * Mr.data()[143] * Mr.data()
		[189] * Mr.data()[231]) + Mr.data()[127] * Mr.data()[188] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[142] * Mr.data()[98] * Mr.data()
		[189] * Mr.data()[261]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[219]
		* Mr.data()[231]) + Mr.data()[142] * Mr.data()[113] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[142] * Mr.data()[113] * Mr.data()[204] *
		Mr.data()[231]) + Mr.data()[142] * Mr.data()[128] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[99] * Mr.data()
		[261]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[114] * Mr.data()[246]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[129] * Mr.data()
		[231]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[99] * Mr.data()[246]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[114] * Mr.data()
		[231]) - Mr.data()[142] * Mr.data()[218] * Mr.data()[99] * Mr.data()[231]) + Mr.data()[157] * Mr.data()[98] * Mr.data()[189] * Mr.data()[246])
		+ Mr.data()[157] * Mr.data()[98] * Mr.data()[204] * Mr.data()[231]) + Mr.data()[157] * Mr.data()[113] * Mr.data()[189] * Mr.data()[231]) -
		Mr.data()[157] * Mr.data()[188] * Mr.data()[99] * Mr.data()[246]) - Mr.data()[157] * Mr.data()[188] * Mr.data()[114] * Mr.data()[231]) - Mr.data()
		[157] * Mr.data()[203] * Mr.data()[99] * Mr.data()[231]) + Mr.data()[172] * Mr.data()[98] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[172]
		* Mr.data()[188] * Mr.data()[99] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[98] * Mr.data()[144] * Mr.data()[261]) - Mr.data()[187] * Mr.data()
		[98] * Mr.data()[159] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[98] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[113]
		* Mr.data()[144] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[113] * Mr.data()[159] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[128] *
		Mr.data()[144] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[143] * Mr.data()[99] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[143] * Mr.data()
		[114] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[143] * Mr.data()[129] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[158] * Mr.data()
		[99] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[158] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[173] * Mr.data()[99]
		* Mr.data()[231]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[144] * Mr.data()[246]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[159] * Mr.data()
		[231]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[99] * Mr.data()
		[246]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[99] * Mr.data()
		[231]) - Mr.data()[217] * Mr.data()[98] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[143] * Mr.data()[99] * Mr.data()[231])
		+ Mr.data()[96] * Mr.data()[143] * Mr.data()[189] * Mr.data()[262]) + Mr.data()[96] * Mr.data()[143] * Mr.data()[204] * Mr.data()[247]) + Mr.data()
		[96] * Mr.data()[143] * Mr.data()[219] * Mr.data()[232]) + Mr.data()[96] * Mr.data()[158] * Mr.data()[189] * Mr.data()[247]) + Mr.data()[96]
		* Mr.data()[158] * Mr.data()[204] * Mr.data()[232]) + Mr.data()[96] * Mr.data()[173] * Mr.data()[189] * Mr.data()[232]) - Mr.data()[96] * Mr.data()
		[188] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[188] * Mr.data()[159] * Mr.data()[247]) - Mr.data()[96] * Mr.data()[188]
		* Mr.data()[174] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[144] * Mr.data()[247]) - Mr.data()[96] * Mr.data()[203] * Mr.data()
		[159] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[144] * Mr.data()[232]) + Mr.data()[111] * Mr.data()[143] * Mr.data()
		[189] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[204] * Mr.data()[232]) + Mr.data()[111] * Mr.data()[158] * Mr.data()
		[189] * Mr.data()[232]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[144] * Mr.data()[247]) - Mr.data()[111] * Mr.data()[188] * Mr.data()
		[159] * Mr.data()[232]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[144] * Mr.data()[232]) + Mr.data()[126] * Mr.data()[143] * Mr.data()
		[189] * Mr.data()[232]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[141] * Mr.data()[98] * Mr.data()
		[189] * Mr.data()[262]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[219]
		* Mr.data()[232]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[204] *
		Mr.data()[232]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[189] * Mr.data()[232]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[99] * Mr.data()
		[262]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[114] * Mr.data()[247]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[129] * Mr.data()
		[232]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[99] * Mr.data()[247]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[114] * Mr.data()
		[232]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[99] * Mr.data()[232]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[189] * Mr.data()[247])
		- Mr.data()[156] * Mr.data()[98] * Mr.data()[204] * Mr.data()[232]) - Mr.data()[156] * Mr.data()[113] * Mr.data()[189] * Mr.data()[232]) +
		Mr.data()[156] * Mr.data()[188] * Mr.data()[99] * Mr.data()[247]) + Mr.data()[156] * Mr.data()[188] * Mr.data()[114] * Mr.data()[232]) + Mr.data()
		[156] * Mr.data()[203] * Mr.data()[99] * Mr.data()[232]) - Mr.data()[171] * Mr.data()[98] * Mr.data()[189] * Mr.data()[232]) + Mr.data()[171]
		* Mr.data()[188] * Mr.data()[99] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[98] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[186] * Mr.data()
		[98] * Mr.data()[159] * Mr.data()[247]) + Mr.data()[186] * Mr.data()[98] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[113]
		* Mr.data()[144] * Mr.data()[247]) + Mr.data()[186] * Mr.data()[113] * Mr.data()[159] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[128] *
		Mr.data()[144] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[143] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[143] * Mr.data()
		[114] * Mr.data()[247]) - Mr.data()[186] * Mr.data()[143] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[158] * Mr.data()
		[99] * Mr.data()[247]) - Mr.data()[186] * Mr.data()[158] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[173] * Mr.data()[99]
		* Mr.data()[232]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[144] * Mr.data()[247]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[159] * Mr.data()
		[232]) + Mr.data()[201] * Mr.data()[113] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[99] * Mr.data()
		[247]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[158] * Mr.data()[99] * Mr.data()
		[232]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[216] * Mr.data()[143] * Mr.data()[99] * Mr.data()[232])
		- Mr.data()[96] * Mr.data()[142] * Mr.data()[189] * Mr.data()[263]) - Mr.data()[96] * Mr.data()[142] * Mr.data()[204] * Mr.data()[248]) - Mr.data()
		[96] * Mr.data()[142] * Mr.data()[219] * Mr.data()[233]) - Mr.data()[96] * Mr.data()[157] * Mr.data()[189] * Mr.data()[248]) - Mr.data()[96]
		* Mr.data()[157] * Mr.data()[204] * Mr.data()[233]) - Mr.data()[96] * Mr.data()[172] * Mr.data()[189] * Mr.data()[233]) + Mr.data()[96] * Mr.data()
		[187] * Mr.data()[144] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[187] * Mr.data()[159] * Mr.data()[248]) + Mr.data()[96] * Mr.data()[187]
		* Mr.data()[174] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[202] * Mr.data()[144] * Mr.data()[248]) + Mr.data()[96] * Mr.data()[202] * Mr.data()
		[159] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[144] * Mr.data()[233]) - Mr.data()[111] * Mr.data()[142] * Mr.data()
		[189] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[204] * Mr.data()[233]) - Mr.data()[111] * Mr.data()[157] * Mr.data()
		[189] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[187] * Mr.data()[144] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[187] * Mr.data()
		[159] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[144] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[142] * Mr.data()
		[189] * Mr.data()[233]) + Mr.data()[126] * Mr.data()[187] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[141] * Mr.data()[97] * Mr.data()
		[189] * Mr.data()[263]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[219]
		* Mr.data()[233]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[204] *
		Mr.data()[233]) + Mr.data()[141] * Mr.data()[127] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[99] * Mr.data()
		[263]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[114] * Mr.data()[248]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[129] * Mr.data()
		[233]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[99] * Mr.data()[248]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[114] * Mr.data()
		[233]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[99] * Mr.data()[233]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[189] * Mr.data()[248])
		+ Mr.data()[156] * Mr.data()[97] * Mr.data()[204] * Mr.data()[233]) + Mr.data()[156] * Mr.data()[112] * Mr.data()[189] * Mr.data()[233]) -
		Mr.data()[156] * Mr.data()[187] * Mr.data()[99] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[187] * Mr.data()[114] * Mr.data()[233]) - Mr.data()
		[156] * Mr.data()[202] * Mr.data()[99] * Mr.data()[233]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[171]
		* Mr.data()[187] * Mr.data()[99] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[97] * Mr.data()[144] * Mr.data()[263]) - Mr.data()[186] * Mr.data()
		[97] * Mr.data()[159] * Mr.data()[248]) - Mr.data()[186] * Mr.data()[97] * Mr.data()[174] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[112]
		* Mr.data()[144] * Mr.data()[248]) - Mr.data()[186] * Mr.data()[112] * Mr.data()[159] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[127] *
		Mr.data()[144] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[142] * Mr.data()[99] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[142] * Mr.data()
		[114] * Mr.data()[248]) + Mr.data()[186] * Mr.data()[142] * Mr.data()[129] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[157] * Mr.data()
		[99] * Mr.data()[248]) + Mr.data()[186] * Mr.data()[157] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[172] * Mr.data()[99]
		* Mr.data()[233]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[144] * Mr.data()[248]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[159] * Mr.data()
		[233]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[99] * Mr.data()
		[248]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[99] * Mr.data()
		[233]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[216] * Mr.data()[142] * Mr.data()[99] * Mr.data()[233])
		+ Mr.data()[96] * Mr.data()[142] * Mr.data()[188] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[142] * Mr.data()[203] * Mr.data()[249]) + Mr.data()
		[96] * Mr.data()[142] * Mr.data()[218] * Mr.data()[234]) + Mr.data()[96] * Mr.data()[157] * Mr.data()[188] * Mr.data()[249]) + Mr.data()[96]
		* Mr.data()[157] * Mr.data()[203] * Mr.data()[234]) + Mr.data()[96] * Mr.data()[172] * Mr.data()[188] * Mr.data()[234]) - Mr.data()[96] * Mr.data()
		[187] * Mr.data()[143] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[187] * Mr.data()[158] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[187]
		* Mr.data()[173] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[143] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[202] * Mr.data()
		[158] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[143] * Mr.data()[234]) + Mr.data()[111] * Mr.data()[142] * Mr.data()
		[188] * Mr.data()[249]) + Mr.data()[111] * Mr.data()[142] * Mr.data()[203] * Mr.data()[234]) + Mr.data()[111] * Mr.data()[157] * Mr.data()
		[188] * Mr.data()[234]) - Mr.data()[111] * Mr.data()[187] * Mr.data()[143] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[187] * Mr.data()
		[158] * Mr.data()[234]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[143] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[142] * Mr.data()
		[188] * Mr.data()[234]) - Mr.data()[126] * Mr.data()[187] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[141] * Mr.data()[97] * Mr.data()
		[188] * Mr.data()[264]) - Mr.data()[141] * Mr.data()[97] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[97] * Mr.data()[218]
		* Mr.data()[234]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[203] *
		Mr.data()[234]) - Mr.data()[141] * Mr.data()[127] * Mr.data()[188] * Mr.data()[234]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[98] * Mr.data()
		[264]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[113] * Mr.data()[249]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[128] * Mr.data()
		[234]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[113] * Mr.data()
		[234]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[98] * Mr.data()[234]) - Mr.data()[156] * Mr.data()[97] * Mr.data()[188] * Mr.data()[249])
		- Mr.data()[156] * Mr.data()[97] * Mr.data()[203] * Mr.data()[234]) - Mr.data()[156] * Mr.data()[112] * Mr.data()[188] * Mr.data()[234]) +
		Mr.data()[156] * Mr.data()[187] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[187] * Mr.data()[113] * Mr.data()[234]) + Mr.data()
		[156] * Mr.data()[202] * Mr.data()[98] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[97] * Mr.data()[188] * Mr.data()[234]) + Mr.data()[171]
		* Mr.data()[187] * Mr.data()[98] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[97] * Mr.data()[143] * Mr.data()[264]) + Mr.data()[186] * Mr.data()
		[97] * Mr.data()[158] * Mr.data()[249]) + Mr.data()[186] * Mr.data()[97] * Mr.data()[173] * Mr.data()[234])
		+ Mr.data()[186] * Mr.data()[112] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[186] * Mr.data()[112] * Mr.data()
		[158] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[127] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[186]
		* Mr.data()[142] * Mr.data()[98] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[142] * Mr.data()[113] * Mr.data()[249])
		- Mr.data()[186] * Mr.data()[142] * Mr.data()[128] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[98] *
		Mr.data()[249]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[172] *
		Mr.data()[98] * Mr.data()[234]) + Mr.data()[201] * Mr.data()[97] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[97]
		* Mr.data()[158] * Mr.data()[234]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[201] * Mr.data()
		[142] * Mr.data()[98] * Mr.data()[249]) - Mr.data()[201] * Mr.data()[142] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[201] *
		Mr.data()[157] * Mr.data()[98] * Mr.data()[234]) + Mr.data()[216] * Mr.data()[97] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[216] * Mr.data()
		[142] * Mr.data()[98] * Mr.data()[234];
	cq[3] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((Mr.data()
		[97] * Mr.data()[188] * Mr.data()[159] * Mr.data()[261] - Mr.data()[97] * Mr.data()[143] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[97] *
		Mr.data()[158] * Mr.data()[189] * Mr.data()[261]) - Mr.data()[97] * Mr.data()[158] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[97] * Mr.data()
		[158] * Mr.data()[219] * Mr.data()[231]) - Mr.data()[97] * Mr.data()[173] * Mr.data()[189] * Mr.data()[246]) - Mr.data()[97] * Mr.data()[173]
		* Mr.data()[204] * Mr.data()[231]) - Mr.data()[97] * Mr.data()[143] * Mr.data()[204] * Mr.data()[261]) + Mr.data()[97] * Mr.data()[188] * Mr.data()
		[174] * Mr.data()[246]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[144] * Mr.data()[261]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[159]
		* Mr.data()[246]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[174] * Mr.data()[231]) + Mr.data()[97] * Mr.data()[218] * Mr.data()[144] * Mr.data()
		[246]) + Mr.data()[97] * Mr.data()[218] * Mr.data()[159] * Mr.data()[231]) - Mr.data()[112] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[261]) - Mr.data()[112] * Mr.data()[143] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[143] * Mr.data()[219] * Mr.data()
		[231]) - Mr.data()[112] * Mr.data()[158] * Mr.data()[189] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[158] * Mr.data()[204] * Mr.data()
		[231]) - Mr.data()[112] * Mr.data()[173] * Mr.data()[189] * Mr.data()[231]) + Mr.data()[112] * Mr.data()[188] * Mr.data()[144] * Mr.data()
		[261]) + Mr.data()[112] * Mr.data()[188] * Mr.data()[159] * Mr.data()[246]) + Mr.data()[112] * Mr.data()[188] * Mr.data()[174] * Mr.data()
		[231]) + Mr.data()[112] * Mr.data()[203] * Mr.data()[144] * Mr.data()[246]) + Mr.data()[112] * Mr.data()[203] * Mr.data()[159] * Mr.data()
		[231]) + Mr.data()[112] * Mr.data()[218] * Mr.data()[144] * Mr.data()[231]) - Mr.data()[127] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[246]) - Mr.data()[127] * Mr.data()[143] * Mr.data()[204] * Mr.data()[231]) - Mr.data()[127] * Mr.data()[158] * Mr.data()[189] * Mr.data()
		[231]) + Mr.data()[127] * Mr.data()[188] * Mr.data()[144] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[188] * Mr.data()[159] * Mr.data()
		[231]) + Mr.data()[127] * Mr.data()[203] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[204] * Mr.data()
		[261]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[142] * Mr.data()[113] * Mr.data()[189] * Mr.data()
		[261]) + Mr.data()[142] * Mr.data()[113] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[142] * Mr.data()[113] * Mr.data()[219] * Mr.data()
		[231]) + Mr.data()[142] * Mr.data()[128] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[142] * Mr.data()[128] * Mr.data()[204] * Mr.data()
		[231]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[129] * Mr.data()
		[246]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[99] * Mr.data()[261]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[114] * Mr.data()
		[246]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[129] * Mr.data()[231]) - Mr.data()[142] * Mr.data()[218] * Mr.data()[99] * Mr.data()
		[246]) - Mr.data()[142] * Mr.data()[218] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[157] * Mr.data()[98] * Mr.data()[189] * Mr.data()
		[261]) + Mr.data()[157] * Mr.data()[98] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[98] * Mr.data()[219] * Mr.data()[231])
		+ Mr.data()[157] * Mr.data()[113] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[113] * Mr.data()[204] * Mr.data()[231]) +
		Mr.data()[157] * Mr.data()[128] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[157] * Mr.data()[188] * Mr.data()[99] * Mr.data()[261]) - Mr.data()
		[157] * Mr.data()[188] * Mr.data()[114] * Mr.data()[246]) - Mr.data()[157] * Mr.data()[188] * Mr.data()[129] * Mr.data()[231]) - Mr.data()
		[157] * Mr.data()[203] * Mr.data()[99] * Mr.data()[246]) - Mr.data()[157] * Mr.data()[203] * Mr.data()[114] * Mr.data()[231]) - Mr.data()
		[157] * Mr.data()[218] * Mr.data()[99] * Mr.data()[231]) + Mr.data()[172] * Mr.data()[98] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[172]
		* Mr.data()[98] * Mr.data()[204] * Mr.data()[231]) + Mr.data()[172] * Mr.data()[113] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[172] *
		Mr.data()[188] * Mr.data()[99] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[188] * Mr.data()[114] * Mr.data()[231]) - Mr.data()[172] * Mr.data()
		[203] * Mr.data()[99] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[98] * Mr.data()[159] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[98]
		* Mr.data()[174] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[113] * Mr.data()[144] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[113] *
		Mr.data()[159] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[113] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[128] * Mr.data()
		[144] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[128] * Mr.data()[159] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[143] * Mr.data()
		[114] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[143] * Mr.data()[129] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[158] * Mr.data()
		[99] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[158] * Mr.data()[114] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[158] * Mr.data()
		[129] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[173] * Mr.data()[99] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[173] * Mr.data()
		[114] * Mr.data()[231]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[144] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[159]
		* Mr.data()[246]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[144] *
		Mr.data()[246]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[159] * Mr.data()[231]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[144] * Mr.data()
		[231]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[99] * Mr.data()[261]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[114] * Mr.data()
		[246]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[129] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[99] * Mr.data()
		[246]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[99] * Mr.data()
		[231]) - Mr.data()[217] * Mr.data()[98] * Mr.data()[144] * Mr.data()[246]) - Mr.data()[217] * Mr.data()[98] * Mr.data()[159] * Mr.data()[231])
		- Mr.data()[217] * Mr.data()[113] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[143] * Mr.data()[99] * Mr.data()[246]) +
		Mr.data()[217] * Mr.data()[143] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[158] * Mr.data()[99] * Mr.data()[231]) + Mr.data()
		[96] * Mr.data()[143] * Mr.data()[204] * Mr.data()[262]) + Mr.data()[96] * Mr.data()[143] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[96]
		* Mr.data()[158] * Mr.data()[189] * Mr.data()[262]) + Mr.data()[96] * Mr.data()[158] * Mr.data()[204] * Mr.data()[247]) + Mr.data()[96] * Mr.data()
		[158] * Mr.data()[219] * Mr.data()[232]) + Mr.data()[96] * Mr.data()[173] * Mr.data()[189] * Mr.data()[247]) + Mr.data()[96] * Mr.data()[173]
		* Mr.data()[204] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[188] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[188] * Mr.data()
		[174] * Mr.data()[247]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[159]
		* Mr.data()[247]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[144] * Mr.data()
		[247]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[159] * Mr.data()[232]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[262]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[204] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[219] * Mr.data()
		[232]) + Mr.data()[111] * Mr.data()[158] * Mr.data()[189] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[158] * Mr.data()[204] * Mr.data()
		[232]) + Mr.data()[111] * Mr.data()[173] * Mr.data()[189] * Mr.data()[232]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[144] * Mr.data()
		[262]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[159] * Mr.data()[247]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[174] * Mr.data()
		[232]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[144] * Mr.data()[247]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[159] * Mr.data()
		[232]) - Mr.data()[111] * Mr.data()[218] * Mr.data()[144] * Mr.data()[232]) + Mr.data()[126] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[247]) + Mr.data()[126] * Mr.data()[143] * Mr.data()[204] * Mr.data()[232]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[189] * Mr.data()
		[232]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[144] * Mr.data()[247]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[159] * Mr.data()
		[232]) - Mr.data()[126] * Mr.data()[203] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[204] * Mr.data()
		[262]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[219] * Mr.data()[247]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[189] * Mr.data()
		[262]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[219] * Mr.data()
		[232]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[204] * Mr.data()
		[232]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[129] * Mr.data()
		[247]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[99] * Mr.data()[262]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[114] * Mr.data()
		[247]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[129] * Mr.data()[232]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[99] * Mr.data()
		[247]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[189] * Mr.data()
		[262]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[219] * Mr.data()[232])
		- Mr.data()[156] * Mr.data()[113] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[156] * Mr.data()[113] * Mr.data()[204] * Mr.data()[232]) -
		Mr.data()[156] * Mr.data()[128] * Mr.data()[189] * Mr.data()[232]) + Mr.data()[156] * Mr.data()[188] * Mr.data()[99] * Mr.data()[262]) + Mr.data()
		[156] * Mr.data()[188] * Mr.data()[114] * Mr.data()[247]) + Mr.data()[156] * Mr.data()[188] * Mr.data()[129] * Mr.data()[232]) + Mr.data()
		[156] * Mr.data()[203] * Mr.data()[99] * Mr.data()[247]) + Mr.data()[156] * Mr.data()[203] * Mr.data()[114] * Mr.data()[232]) + Mr.data()
		[156] * Mr.data()[218] * Mr.data()[99] * Mr.data()[232]) - Mr.data()[171] * Mr.data()[98] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[171]
		* Mr.data()[98] * Mr.data()[204] * Mr.data()[232]) - Mr.data()[171] * Mr.data()[113] * Mr.data()[189] * Mr.data()[232]) + Mr.data()[171] *
		Mr.data()[188] * Mr.data()[99] * Mr.data()[247]) + Mr.data()[171] * Mr.data()[188] * Mr.data()[114] * Mr.data()[232]) + Mr.data()[171] * Mr.data()
		[203] * Mr.data()[99] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[98] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[186] * Mr.data()[98]
		* Mr.data()[174] * Mr.data()[247]) + Mr.data()[186] * Mr.data()[113] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[186] * Mr.data()[113] *
		Mr.data()[159] * Mr.data()[247]) + Mr.data()[186] * Mr.data()[113] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[128] * Mr.data()
		[144] * Mr.data()[247]) + Mr.data()[186] * Mr.data()[128] * Mr.data()[159] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[143] * Mr.data()
		[114] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[143] * Mr.data()[129] * Mr.data()[247]) - Mr.data()[186] * Mr.data()[158] * Mr.data()
		[99] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[158] * Mr.data()[114] * Mr.data()[247]) - Mr.data()[186] * Mr.data()[158] * Mr.data()
		[129] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[173] * Mr.data()[99] * Mr.data()[247]) - Mr.data()[186] * Mr.data()[173] * Mr.data()
		[114] * Mr.data()[232]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[159]
		* Mr.data()[247]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[201] * Mr.data()[113] * Mr.data()[144] *
		Mr.data()[247]) + Mr.data()[201] * Mr.data()[113] * Mr.data()[159] * Mr.data()[232]) + Mr.data()[201] * Mr.data()[128] * Mr.data()[144] * Mr.data()
		[232]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[114] * Mr.data()
		[247]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[158] * Mr.data()[99] * Mr.data()
		[247]) - Mr.data()[201] * Mr.data()[158] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[173] * Mr.data()[99] * Mr.data()
		[232]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[144] * Mr.data()[247]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[159] * Mr.data()[232])
		+ Mr.data()[216] * Mr.data()[113] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[216] * Mr.data()[143] * Mr.data()[99] * Mr.data()[247]) -
		Mr.data()[216] * Mr.data()[143] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[216] * Mr.data()[158] * Mr.data()[99] * Mr.data()[232]) - Mr.data()
		[96] * Mr.data()[142] * Mr.data()[204] * Mr.data()[263]) - Mr.data()[96] * Mr.data()[142] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[96]
		* Mr.data()[157] * Mr.data()[189] * Mr.data()[263]) - Mr.data()[96] * Mr.data()[157] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[96] * Mr.data()
		[157] * Mr.data()[219] * Mr.data()[233]) - Mr.data()[96] * Mr.data()[172] * Mr.data()[189] * Mr.data()[248]) - Mr.data()[96] * Mr.data()[172]
		* Mr.data()[204] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[187] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[187] * Mr.data()
		[174] * Mr.data()[248]) + Mr.data()[96] * Mr.data()[202] * Mr.data()[144] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[202] * Mr.data()[159]
		* Mr.data()[248]) + Mr.data()[96] * Mr.data()[202] * Mr.data()[174] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[144] * Mr.data()
		[248]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[159] * Mr.data()[233]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[189] * Mr.data()
		[263]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[219] * Mr.data()
		[233]) - Mr.data()[111] * Mr.data()[157] * Mr.data()[189] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[157] * Mr.data()[204] * Mr.data()
		[233]) - Mr.data()[111] * Mr.data()[172] * Mr.data()[189] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[187] * Mr.data()[144] * Mr.data()
		[263]) + Mr.data()[111] * Mr.data()[187] * Mr.data()[159] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[187] * Mr.data()[174] * Mr.data()
		[233]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[144] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[159] * Mr.data()
		[233]) + Mr.data()[111] * Mr.data()[217] * Mr.data()[144] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[142] * Mr.data()[189] * Mr.data()
		[248]) - Mr.data()[126] * Mr.data()[142] * Mr.data()[204] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[157] * Mr.data()[189] * Mr.data()
		[233]) + Mr.data()[126] * Mr.data()[187] * Mr.data()[144] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[187] * Mr.data()[159] * Mr.data()
		[233]) + Mr.data()[126] * Mr.data()[202] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[204] * Mr.data()
		[263]) + Mr.data()[141] * Mr.data()[97] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[189] * Mr.data()
		[263]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[219] * Mr.data()
		[233]) + Mr.data()[141] * Mr.data()[127] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[127] * Mr.data()[204] * Mr.data()
		[233]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[187] * Mr.data()[129] * Mr.data()
		[248]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[99] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[114] * Mr.data()
		[248]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[129] * Mr.data()[233]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[99] * Mr.data()
		[248]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[189] * Mr.data()
		[263]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[219] * Mr.data()[233])
		+ Mr.data()[156] * Mr.data()[112] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[112] * Mr.data()[204] * Mr.data()[233]) +
		Mr.data()[156] * Mr.data()[127] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[156] * Mr.data()[187] * Mr.data()[99] * Mr.data()[263]) - Mr.data()
		[156] * Mr.data()[187] * Mr.data()[114] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[187] * Mr.data()[129] * Mr.data()[233]) - Mr.data()
		[156] * Mr.data()[202] * Mr.data()[99] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[202] * Mr.data()[114] * Mr.data()[233]) - Mr.data()
		[156] * Mr.data()[217] * Mr.data()[99] * Mr.data()[233]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[171]
		* Mr.data()[97] * Mr.data()[204] * Mr.data()[233]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[171] *
		Mr.data()[187] * Mr.data()[99] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[187] * Mr.data()[114] * Mr.data()[233]) - Mr.data()[171] * Mr.data()
		[202] * Mr.data()[99] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[97] * Mr.data()[159] * Mr.data()[263]) - Mr.data()[186] * Mr.data()[97]
		* Mr.data()[174] * Mr.data()[248]) - Mr.data()[186] * Mr.data()[112] * Mr.data()[144] * Mr.data()[263]) - Mr.data()[186] * Mr.data()[112] *
		Mr.data()[159] * Mr.data()[248]) - Mr.data()[186] * Mr.data()[112] * Mr.data()[174] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[127] * Mr.data()
		[144] * Mr.data()[248]) - Mr.data()[186] * Mr.data()[127] * Mr.data()[159] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[142] * Mr.data()
		[114] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[142] * Mr.data()[129] * Mr.data()[248]) + Mr.data()[186] * Mr.data()[157] * Mr.data()
		[99] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[157] * Mr.data()[114] * Mr.data()[248]) + Mr.data()[186] * Mr.data()[157] * Mr.data()
		[129] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[172] * Mr.data()[99] * Mr.data()[248]) + Mr.data()[186] * Mr.data()[172] * Mr.data()
		[114] * Mr.data()[233]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[144] * Mr.data()[263]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[159]
		* Mr.data()[248]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[174] * Mr.data()[233]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[144] *
		Mr.data()[248]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[159] * Mr.data()[233]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[144] * Mr.data()
		[233]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[99] * Mr.data()[263]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[114] * Mr.data()
		[248]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[129] * Mr.data()[233]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[99] * Mr.data()
		[248]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[99] * Mr.data()
		[233]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[144] * Mr.data()[248]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[159] * Mr.data()[233])
		- Mr.data()[216] * Mr.data()[112] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[216] * Mr.data()[142] * Mr.data()[99] * Mr.data()[248]) +
		Mr.data()[216] * Mr.data()[142] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[216] * Mr.data()[157] * Mr.data()[99] * Mr.data()[233]) + Mr.data()
		[96] * Mr.data()[142] * Mr.data()[203] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[142] * Mr.data()[218] * Mr.data()[249]) + Mr.data()[96]
		* Mr.data()[157] * Mr.data()[188] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[157] * Mr.data()[203] * Mr.data()[249]) + Mr.data()[96] * Mr.data()
		[157] * Mr.data()[218] * Mr.data()[234]) + Mr.data()[96] * Mr.data()[172] * Mr.data()[188] * Mr.data()[249]) + Mr.data()[96] * Mr.data()[172]
		* Mr.data()[203] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[187] * Mr.data()[158] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[187] * Mr.data()
		[173] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[143] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[158]
		* Mr.data()[249]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[173] * Mr.data()[234]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[143] * Mr.data()
		[249]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[158] * Mr.data()[234]) + Mr.data()[111] * Mr.data()[142] * Mr.data()[188] * Mr.data()
		[264]) + Mr.data()[111] * Mr.data()[142] * Mr.data()[203] * Mr.data()[249]) + Mr.data()[111] * Mr.data()[142] * Mr.data()[218] * Mr.data()
		[234]) + Mr.data()[111] * Mr.data()[157] * Mr.data()[188] * Mr.data()[249]) + Mr.data()[111] * Mr.data()[157] * Mr.data()[203] * Mr.data()
		[234]) + Mr.data()[111] * Mr.data()[172] * Mr.data()[188] * Mr.data()[234]) - Mr.data()[111] * Mr.data()[187] * Mr.data()[143] * Mr.data()
		[264]) - Mr.data()[111] * Mr.data()[187] * Mr.data()[158] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[187] * Mr.data()[173] * Mr.data()
		[234]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[143] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[158] * Mr.data()
		[234]) - Mr.data()[111] * Mr.data()[217] * Mr.data()[143] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[142] * Mr.data()[188] * Mr.data()
		[249]) + Mr.data()[126] * Mr.data()[142] * Mr.data()[203] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[157] * Mr.data()[188] * Mr.data()
		[234]) - Mr.data()[126] * Mr.data()[187] * Mr.data()[143] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[187] * Mr.data()[158] * Mr.data()
		[234]) - Mr.data()[126] * Mr.data()[202] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[141] * Mr.data()[97] * Mr.data()[203] * Mr.data()
		[264]) - Mr.data()[141] * Mr.data()[97] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[188] * Mr.data()
		[264]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[218] * Mr.data()
		[234]) - Mr.data()[141] * Mr.data()[127] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[127] * Mr.data()[203] * Mr.data()
		[234]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[141] * Mr.data()[187] * Mr.data()[128] * Mr.data()
		[249]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[98] * Mr.data()[264]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[113] * Mr.data()
		[249]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[128] * Mr.data()[234]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[98] * Mr.data()
		[249]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[156] * Mr.data()[97] * Mr.data()[188] * Mr.data()
		[264]) - Mr.data()[156] * Mr.data()[97] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[156] * Mr.data()[97] * Mr.data()[218] * Mr.data()[234])
		- Mr.data()[156] * Mr.data()[112] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[156] * Mr.data()[112] * Mr.data()[203] * Mr.data()[234]) -
		Mr.data()[156] * Mr.data()[127] * Mr.data()[188] * Mr.data()[234]) + Mr.data()[156] * Mr.data()[187] * Mr.data()[98] * Mr.data()[264]) + Mr.data()
		[156] * Mr.data()[187] * Mr.data()[113] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[187] * Mr.data()[128] * Mr.data()[234]) + Mr.data()
		[156] * Mr.data()[202] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[202] * Mr.data()[113] * Mr.data()[234]) + Mr.data()
		[156] * Mr.data()[217] * Mr.data()[98] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[97] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[171]
		* Mr.data()[97] * Mr.data()[203] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[112] * Mr.data()[188] * Mr.data()[234]) + Mr.data()[171] *
		Mr.data()[187] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[187] * Mr.data()[113] * Mr.data()[234]) + Mr.data()[171] * Mr.data()
		[202] * Mr.data()[98] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[97] * Mr.data()[158] * Mr.data()[264]) + Mr.data()[186] * Mr.data()[97]
		* Mr.data()[173] * Mr.data()[249]) + Mr.data()[186] * Mr.data()[112] * Mr.data()[143] * Mr.data()[264]) + Mr.data()[186] * Mr.data()[112] *
		Mr.data()[158] * Mr.data()[249]) + Mr.data()[186] * Mr.data()[112] * Mr.data()[173] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[127] * Mr.data()
		[143] * Mr.data()[249]) + Mr.data()[186] * Mr.data()[127] * Mr.data()[158] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[142] * Mr.data()
		[113] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[142] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[186] * Mr.data()[157] * Mr.data()
		[98] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[113] * Mr.data()[249]) - Mr.data()[186] * Mr.data()[157] * Mr.data()
		[128] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[172] * Mr.data()[98] * Mr.data()[249]) - Mr.data()[186] * Mr.data()[172] * Mr.data()
		[113] * Mr.data()[234]) + Mr.data()[201] * Mr.data()[97] * Mr.data()[143] * Mr.data()[264]) + Mr.data()
		[201] * Mr.data()[97] * Mr.data()[158] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[97] * Mr.data()[173] *
		Mr.data()[234]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[112]
		* Mr.data()[158] * Mr.data()[234]) + Mr.data()[201] * Mr.data()[127] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[201]
		* Mr.data()[142] * Mr.data()[98] * Mr.data()[264]) - Mr.data()[201] * Mr.data()[142] * Mr.data()[113] * Mr.data()[249]) -
		Mr.data()[201] * Mr.data()[142] * Mr.data()[128] * Mr.data()[234]) - Mr.data()[201] * Mr.data()[157] * Mr.data()[98] * Mr.data()
		[249]) - Mr.data()[201] * Mr.data()[157] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[98]
		* Mr.data()[234]) + Mr.data()[216] * Mr.data()[97] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[97] * Mr.data()[158]
		* Mr.data()[234]) + Mr.data()[216] * Mr.data()[112] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[216] * Mr.data()[142] * Mr.data()[98]
		* Mr.data()[249]) - Mr.data()[216] * Mr.data()[142] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[216] * Mr.data()[157] * Mr.data()[98] *
		Mr.data()[234];
	cq[4] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((Mr.data()[97] *
		Mr.data()[188] * Mr.data()[174] * Mr.data()[261] - Mr.data()[97] * Mr.data()[158] * Mr.data()[204] * Mr.data()[261]) - Mr.data()[97] * Mr.data()[158]
		* Mr.data()[219] * Mr.data()[246]) - Mr.data()[97] * Mr.data()[173] * Mr.data()[189] * Mr.data()[261]) - Mr.data()[97] * Mr.data()[173] * Mr.data()
		[204] * Mr.data()[246]) - Mr.data()[97] * Mr.data()[173] * Mr.data()[219] * Mr.data()[231]) - Mr.data()[97] * Mr.data()[143] * Mr.data()[219]
		* Mr.data()[261]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[97] * Mr.data()[203] * Mr.data()[174] * Mr.data()
		[246]) + Mr.data()[97] * Mr.data()[218] * Mr.data()[144] * Mr.data()[261]) + Mr.data()[97] * Mr.data()[218] * Mr.data()[159] * Mr.data()[246])
		+ Mr.data()[97] * Mr.data()[218] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[112] * Mr.data()[143] * Mr.data()[204] * Mr.data()[261]) -
		Mr.data()[112] * Mr.data()[143] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[158] * Mr.data()[189] * Mr.data()[261]) - Mr.data()
		[112] * Mr.data()[158] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[158] * Mr.data()[219] * Mr.data()[231]) - Mr.data()
		[112] * Mr.data()[173] * Mr.data()[189] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[173] * Mr.data()[204] * Mr.data()[231]) + Mr.data()
		[112] * Mr.data()[188] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[112] * Mr.data()[188] * Mr.data()[174] * Mr.data()[246]) + Mr.data()
		[112] * Mr.data()[203] * Mr.data()[144] * Mr.data()[261]) + Mr.data()[112] * Mr.data()[203] * Mr.data()[159] * Mr.data()[246]) + Mr.data()
		[112] * Mr.data()[203] * Mr.data()[174] * Mr.data()[231]) + Mr.data()[112] * Mr.data()[218] * Mr.data()[144] * Mr.data()[246]) + Mr.data()
		[112] * Mr.data()[218] * Mr.data()[159] * Mr.data()[231]) - Mr.data()[127] * Mr.data()[143] * Mr.data()[189] * Mr.data()[261]) - Mr.data()
		[127] * Mr.data()[143] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[127] * Mr.data()[143] * Mr.data()[219] * Mr.data()[231]) - Mr.data()
		[127] * Mr.data()[158] * Mr.data()[189] * Mr.data()[246]) - Mr.data()[127] * Mr.data()[158] * Mr.data()[204] * Mr.data()[231]) - Mr.data()
		[127] * Mr.data()[173] * Mr.data()[189] * Mr.data()[231]) + Mr.data()[127] * Mr.data()[188] * Mr.data()[144] * Mr.data()[261]) + Mr.data()
		[127] * Mr.data()[188] * Mr.data()[159] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[188] * Mr.data()[174] * Mr.data()[231]) + Mr.data()
		[127] * Mr.data()[203] * Mr.data()[144] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[203] * Mr.data()[159] * Mr.data()[231]) + Mr.data()
		[127] * Mr.data()[218] * Mr.data()[144] * Mr.data()[231]) + Mr.data()[142] * Mr.data()[98] * Mr.data()[219] * Mr.data()[261]) + Mr.data()
		[142] * Mr.data()[113] * Mr.data()[204] * Mr.data()[261]) + Mr.data()[142] * Mr.data()[113] * Mr.data()[219] * Mr.data()[246]) + Mr.data()
		[142] * Mr.data()[128] * Mr.data()[189] * Mr.data()[261]) + Mr.data()[142] * Mr.data()[128] * Mr.data()[204] * Mr.data()[246]) + Mr.data()
		[142] * Mr.data()[128] * Mr.data()[219] * Mr.data()[231]) - Mr.data()[142] * Mr.data()[188] * Mr.data()[129] * Mr.data()[261]) - Mr.data()
		[142] * Mr.data()[203] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[129] * Mr.data()[246]) - Mr.data()
		[142] * Mr.data()[218] * Mr.data()[99] * Mr.data()[261]) - Mr.data()[142] * Mr.data()[218] * Mr.data()[114] * Mr.data()[246]) - Mr.data()
		[142] * Mr.data()[218] * Mr.data()[129] * Mr.data()[231]) + Mr.data()[157] * Mr.data()[98] * Mr.data()[204] * Mr.data()[261]) + Mr.data()
		[157] * Mr.data()[98] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[113] * Mr.data()[189] * Mr.data()[261]) + Mr.data()
		[157] * Mr.data()[113] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[113] * Mr.data()[219] * Mr.data()[231]) + Mr.data()
		[157] * Mr.data()[128] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[128] * Mr.data()[204] * Mr.data()[231]) - Mr.data()
		[157] * Mr.data()[188] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[157] * Mr.data()[188] * Mr.data()[129] * Mr.data()[246]) - Mr.data()
		[157] * Mr.data()[203] * Mr.data()[99] * Mr.data()[261]) - Mr.data()[157] * Mr.data()[203] * Mr.data()[114] * Mr.data()[246]) - Mr.data()
		[157] * Mr.data()[203] * Mr.data()[129] * Mr.data()[231]) - Mr.data()[157] * Mr.data()[218] * Mr.data()[99] * Mr.data()[246]) - Mr.data()
		[157] * Mr.data()[218] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[172] * Mr.data()[98] * Mr.data()[189] * Mr.data()[261]) + Mr.data()
		[172] * Mr.data()[98] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[98] * Mr.data()[219] * Mr.data()[231]) + Mr.data()[172]
		* Mr.data()[113] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[113] * Mr.data()[204] * Mr.data()[231]) + Mr.data()[172] *
		Mr.data()[128] * Mr.data()[189] * Mr.data()[231]) - Mr.data()[172] * Mr.data()[188] * Mr.data()[99] * Mr.data()[261]) - Mr.data()[172] * Mr.data()
		[188] * Mr.data()[114] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[188] * Mr.data()[129] * Mr.data()[231]) - Mr.data()[172] * Mr.data()
		[203] * Mr.data()[99] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[203] * Mr.data()[114] * Mr.data()[231]) - Mr.data()[172] * Mr.data()
		[218] * Mr.data()[99] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[98] * Mr.data()[174] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[113]
		* Mr.data()[159] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[113] * Mr.data()[174] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[128] *
		Mr.data()[144] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[128] * Mr.data()[159] * Mr.data()[246]) - Mr.data()[187] * Mr.data()[128] * Mr.data()
		[174] * Mr.data()[231]) + Mr.data()[187] * Mr.data()[143] * Mr.data()[129] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[158] * Mr.data()
		[114] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[158] * Mr.data()[129] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[173] * Mr.data()
		[99] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[173] * Mr.data()[114] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[173] * Mr.data()
		[129] * Mr.data()[231]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[159] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[98] * Mr.data()[174]
		* Mr.data()[246]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[144] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[159] *
		Mr.data()[246]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[144] * Mr.data()
		[246]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[159] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[114] * Mr.data()
		[261]) + Mr.data()[202] * Mr.data()[143] * Mr.data()[129] * Mr.data()[246]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[99] * Mr.data()
		[261]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[114] * Mr.data()[246]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[129] * Mr.data()
		[231]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[99] * Mr.data()[246]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[114] * Mr.data()
		[231]) - Mr.data()[217] * Mr.data()[98] * Mr.data()[144] * Mr.data()[261]) - Mr.data()[217] * Mr.data()[98] * Mr.data()[159] * Mr.data()[246])
		- Mr.data()[217] * Mr.data()[98] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[217] * Mr.data()[113] * Mr.data()[144] * Mr.data()[246]) -
		Mr.data()[217] * Mr.data()[113] * Mr.data()[159] * Mr.data()[231]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[144] * Mr.data()[231]) + Mr.data()
		[217] * Mr.data()[143] * Mr.data()[99] * Mr.data()[261]) + Mr.data()[217] * Mr.data()[143] * Mr.data()[114] * Mr.data()[246]) + Mr.data()
		[217] * Mr.data()[143] * Mr.data()[129] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[158] * Mr.data()[99] * Mr.data()[246]) + Mr.data()
		[217] * Mr.data()[158] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[173] * Mr.data()[99] * Mr.data()[231]) + Mr.data()[96]
		* Mr.data()[143] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[96] * Mr.data()[158] * Mr.data()[204] * Mr.data()[262]) + Mr.data()[96] * Mr.data()
		[158] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[96] * Mr.data()[173] * Mr.data()[189] * Mr.data()[262]) + Mr.data()[96] * Mr.data()[173]
		* Mr.data()[204] * Mr.data()[247]) + Mr.data()[96] * Mr.data()[173] * Mr.data()[219] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[188] * Mr.data()
		[174] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[174]
		* Mr.data()[247]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[159] * Mr.data()
		[247]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[204] * Mr.data()
		[262]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[158] * Mr.data()[189] * Mr.data()
		[262]) + Mr.data()[111] * Mr.data()[158] * Mr.data()[204] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[158] * Mr.data()[219] * Mr.data()
		[232]) + Mr.data()[111] * Mr.data()[173] * Mr.data()[189] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[173] * Mr.data()[204] * Mr.data()
		[232]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[174] * Mr.data()
		[247]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[159] * Mr.data()
		[247]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[111] * Mr.data()[218] * Mr.data()[144] * Mr.data()
		[247]) - Mr.data()[111] * Mr.data()[218] * Mr.data()[159] * Mr.data()[232]) + Mr.data()[126] * Mr.data()[143] * Mr.data()[189] * Mr.data()
		[262]) + Mr.data()[126] * Mr.data()[143] * Mr.data()[204] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[143] * Mr.data()[219] * Mr.data()
		[232]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[189] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[204] * Mr.data()
		[232]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[189] * Mr.data()[232]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[144] * Mr.data()
		[262]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[159] * Mr.data()[247]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[174] * Mr.data()
		[232]) - Mr.data()[126] * Mr.data()[203] * Mr.data()[144] * Mr.data()[247]) - Mr.data()[126] * Mr.data()[203] * Mr.data()[159] * Mr.data()
		[232]) - Mr.data()[126] * Mr.data()[218] * Mr.data()[144] * Mr.data()[232]) - Mr.data()[141] * Mr.data()[98] * Mr.data()[219] * Mr.data()
		[262]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[204] * Mr.data()[262]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[219] * Mr.data()
		[247]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[189] * Mr.data()[262]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[204] * Mr.data()
		[247]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[219] * Mr.data()[232]) + Mr.data()[141] * Mr.data()[188] * Mr.data()[129] * Mr.data()
		[262]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[141] * Mr.data()[203] * Mr.data()[129] * Mr.data()
		[247]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[99] * Mr.data()[262]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[114] * Mr.data()
		[247]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[204] * Mr.data()
		[262]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[219] * Mr.data()[247]) - Mr.data()[156] * Mr.data()[113] * Mr.data()[189] * Mr.data()
		[262]) - Mr.data()[156] * Mr.data()[113] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[156] * Mr.data()[113] * Mr.data()[219] * Mr.data()
		[232]) - Mr.data()[156] * Mr.data()[128] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[156] * Mr.data()[128] * Mr.data()[204] * Mr.data()
		[232]) + Mr.data()[156] * Mr.data()[188] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[156] * Mr.data()[188] * Mr.data()[129] * Mr.data()
		[247]) + Mr.data()[156] * Mr.data()[203] * Mr.data()[99] * Mr.data()[262]) + Mr.data()[156] * Mr.data()[203] * Mr.data()[114] * Mr.data()
		[247]) + Mr.data()[156] * Mr.data()[203] * Mr.data()[129] * Mr.data()[232]) + Mr.data()[156] * Mr.data()[218] * Mr.data()[99] * Mr.data()
		[247]) + Mr.data()[156] * Mr.data()[218] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[171] * Mr.data()[98] * Mr.data()[189] * Mr.data()
		[262]) - Mr.data()[171] * Mr.data()[98] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[98] * Mr.data()[219] * Mr.data()[232])
		- Mr.data()[171] * Mr.data()[113] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[113] * Mr.data()[204] * Mr.data()[232]) -
		Mr.data()[171] * Mr.data()[128] * Mr.data()[189] * Mr.data()[232]) + Mr.data()[171] * Mr.data()[188] * Mr.data()[99] * Mr.data()[262]) + Mr.data()
		[171] * Mr.data()[188] * Mr.data()[114] * Mr.data()[247]) + Mr.data()[171] * Mr.data()[188] * Mr.data()[129] * Mr.data()[232]) + Mr.data()
		[171] * Mr.data()[203] * Mr.data()[99] * Mr.data()[247]) + Mr.data()[171] * Mr.data()[203] * Mr.data()[114] * Mr.data()[232]) + Mr.data()
		[171] * Mr.data()[218] * Mr.data()[99] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[98] * Mr.data()[174] * Mr.data()[262]) + Mr.data()[186]
		* Mr.data()[113] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[186] * Mr.data()[113] * Mr.data()[174] * Mr.data()[247]) + Mr.data()[186] *
		Mr.data()[128] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[186] * Mr.data()[128] * Mr.data()[159] * Mr.data()[247]) + Mr.data()[186] * Mr.data()
		[128] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[186] * Mr.data()[143] * Mr.data()[129] * Mr.data()[262]) - Mr.data()[186] * Mr.data()
		[158] * Mr.data()[114] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[158] * Mr.data()[129] * Mr.data()[247]) - Mr.data()[186] * Mr.data()
		[173] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[173] * Mr.data()[114] * Mr.data()[247]) - Mr.data()[186] * Mr.data()
		[173] * Mr.data()[129] * Mr.data()[232]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[201] * Mr.data()[98]
		* Mr.data()[174] * Mr.data()[247]) + Mr.data()[201] * Mr.data()[113] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[201] * Mr.data()[113] *
		Mr.data()[159] * Mr.data()[247]) + Mr.data()[201] * Mr.data()[113] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[201] * Mr.data()[128] * Mr.data()
		[144] * Mr.data()[247]) + Mr.data()[201] * Mr.data()[128] * Mr.data()[159] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[143] * Mr.data()
		[114] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[129] * Mr.data()[247]) - Mr.data()[201] * Mr.data()[158] * Mr.data()
		[99] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[158] * Mr.data()[114] * Mr.data()[247]) - Mr.data()[201] * Mr.data()[158] * Mr.data()
		[129] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[173] * Mr.data()[99] * Mr.data()[247]) - Mr.data()[201] * Mr.data()[173] * Mr.data()
		[114] * Mr.data()[232]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[159]
		* Mr.data()[247]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[216] * Mr.data()[113] * Mr.data()[144] *
		Mr.data()[247]) + Mr.data()[216] * Mr.data()[113] * Mr.data()[159] * Mr.data()[232]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[144] * Mr.data()
		[232]) - Mr.data()[216] * Mr.data()[143] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[216] * Mr.data()[143] * Mr.data()[114] * Mr.data()
		[247]) - Mr.data()[216] * Mr.data()[143] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[216] * Mr.data()[158] * Mr.data()[99] * Mr.data()
		[247]) - Mr.data()[216] * Mr.data()[158] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[99] * Mr.data()
		[232]) - Mr.data()[96] * Mr.data()[142] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[96] * Mr.data()[157] * Mr.data()[204] * Mr.data()[263])
		- Mr.data()[96] * Mr.data()[157] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[96] * Mr.data()[172] * Mr.data()[189] * Mr.data()[263]) - Mr.data()
		[96] * Mr.data()[172] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[96] * Mr.data()[172] * Mr.data()[219] * Mr.data()[233]) + Mr.data()[96]
		* Mr.data()[187] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[202] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[96] * Mr.data()
		[202] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[144] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[217]
		* Mr.data()[159] * Mr.data()[248]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[174] * Mr.data()[233]) - Mr.data()[111] * Mr.data()[142] *
		Mr.data()[204] * Mr.data()[263]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[157] * Mr.data()
		[189] * Mr.data()[263]) - Mr.data()[111] * Mr.data()[157] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[157] * Mr.data()
		[219] * Mr.data()[233]) - Mr.data()[111] * Mr.data()[172] * Mr.data()[189] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[172] * Mr.data()
		[204] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[187] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[187] * Mr.data()
		[174] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[144] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[202] * Mr.data()
		[159] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[174] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[217] * Mr.data()
		[144] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[217] * Mr.data()[159] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[142] * Mr.data()
		[189] * Mr.data()[263]) - Mr.data()[126] * Mr.data()[142] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[142] * Mr.data()
		[219] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[157] * Mr.data()[189] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[157] * Mr.data()
		[204] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[172] * Mr.data()[189] * Mr.data()[233]) + Mr.data()[126] * Mr.data()[187] * Mr.data()
		[144] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[187] * Mr.data()[159] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[187] * Mr.data()
		[174] * Mr.data()[233]) + Mr.data()[126] * Mr.data()[202] * Mr.data()[144] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[202] * Mr.data()
		[159] * Mr.data()[233]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[141] * Mr.data()[97] * Mr.data()
		[219] * Mr.data()[263]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[204] * Mr.data()[263]) + Mr.data()[141] * Mr.data()[112] * Mr.data()
		[219] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[127] * Mr.data()[189] * Mr.data()[263]) + Mr.data()[141] * Mr.data()[127] * Mr.data()
		[204] * Mr.data()[248]) + Mr.data()[141] * Mr.data()[127] * Mr.data()[219] * Mr.data()[233]) - Mr.data()[141] * Mr.data()[187] * Mr.data()
		[129] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[202] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[202] * Mr.data()
		[129] * Mr.data()[248]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[99] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[217] * Mr.data()
		[114] * Mr.data()[248]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[129] * Mr.data()[233]) + Mr.data()[156] * Mr.data()[97] * Mr.data()
		[204] * Mr.data()[263]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[112] * Mr.data()
		[189] * Mr.data()[263]) + Mr.data()[156] * Mr.data()[112] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[112] * Mr.data()
		[219] * Mr.data()[233]) + Mr.data()[156] * Mr.data()[127] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[127] * Mr.data()
		[204] * Mr.data()[233]) - Mr.data()[156] * Mr.data()[187] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[187] * Mr.data()
		[129] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[202] * Mr.data()[99] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[202] * Mr.data()
		[114] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[202] * Mr.data()[129] * Mr.data()[233]) - Mr.data()[156] * Mr.data()[217] * Mr.data()
		[99] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[217] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[189]
		* Mr.data()[263]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[219] * Mr.data()
		[233]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[189] * Mr.data()[248]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[204] * Mr.data()
		[233]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[189] * Mr.data()[233]) - Mr.data()[171] * Mr.data()[187] * Mr.data()[99] * Mr.data()
		[263]) - Mr.data()[171] * Mr.data()[187] * Mr.data()[114] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[187] * Mr.data()[129] * Mr.data()
		[233]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[99] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[114] * Mr.data()
		[233]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[99] * Mr.data()[233]) - Mr.data()[186] * Mr.data()[97] * Mr.data()[174] * Mr.data()[263])
		- Mr.data()[186] * Mr.data()[112] * Mr.data()[159] * Mr.data()[263]) - Mr.data()[186] * Mr.data()[112] * Mr.data()[174] * Mr.data()[248]) -
		Mr.data()[186] * Mr.data()[127] * Mr.data()[144] * Mr.data()[263]) - Mr.data()[186] * Mr.data()[127] * Mr.data()[159] * Mr.data()[248]) - Mr.data()
		[186] * Mr.data()[127] * Mr.data()[174] * Mr.data()[233]) + Mr.data()[186] * Mr.data()[142] * Mr.data()[129] * Mr.data()[263]) + Mr.data()
		[186] * Mr.data()[157] * Mr.data()[114] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[157] * Mr.data()[129] * Mr.data()[248]) + Mr.data()
		[186] * Mr.data()[172] * Mr.data()[99] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[172] * Mr.data()[114] * Mr.data()[248]) + Mr.data()
		[186] * Mr.data()[172] * Mr.data()[129] * Mr.data()[233]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[159] * Mr.data()[263]) - Mr.data()
		[201] * Mr.data()[97] * Mr.data()[174] * Mr.data()[248]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[144] * Mr.data()[263]) - Mr.data()
		[201] * Mr.data()[112] * Mr.data()[159] * Mr.data()[248]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[174] * Mr.data()[233]) - Mr.data()
		[201] * Mr.data()[127] * Mr.data()[144] * Mr.data()[248]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[159] * Mr.data()[233]) + Mr.data()
		[201] * Mr.data()[142] * Mr.data()[114] * Mr.data()[263]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[129] * Mr.data()[248]) + Mr.data()
		[201] * Mr.data()[157] * Mr.data()[99] * Mr.data()[263]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[114] * Mr.data()[248]) + Mr.data()
		[201] * Mr.data()[157] * Mr.data()[129] * Mr.data()[233]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[99] * Mr.data()[248]) + Mr.data()
		[201] * Mr.data()[172] * Mr.data()[114] * Mr.data()[233]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[144] * Mr.data()[263]) - Mr.data()
		[216] * Mr.data()[97] * Mr.data()[159] * Mr.data()[248]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[174] * Mr.data()[233]) - Mr.data()[216]
		* Mr.data()[112] * Mr.data()[144] * Mr.data()[248]) - Mr.data()[216] * Mr.data()[112] * Mr.data()[159] * Mr.data()[233]) - Mr.data()[216] *
		Mr.data()[127] * Mr.data()[144] * Mr.data()[233]) + Mr.data()[216] * Mr.data()[142] * Mr.data()[99] * Mr.data()[263]) + Mr.data()[216] * Mr.data()
		[142] * Mr.data()[114] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[142] * Mr.data()[129] * Mr.data()[233]) + Mr.data()[216] * Mr.data()
		[157] * Mr.data()[99] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[157] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[216] * Mr.data()
		[172] * Mr.data()[99] * Mr.data()[233]) + Mr.data()[96] * Mr.data()[142] * Mr.data()[218] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[157]
		* Mr.data()[203] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[157] * Mr.data()[218] * Mr.data()[249]) + Mr.data()[96] * Mr.data()[172] * Mr.data()
		[188] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[172] * Mr.data()[203] * Mr.data()[249]) + Mr.data()[96] * Mr.data()[172] * Mr.data()[218]
		* Mr.data()[234]) - Mr.data()[96] * Mr.data()[187] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[158] * Mr.data()
		[264]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[173] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[143] * Mr.data()[264])
		- Mr.data()[96] * Mr.data()[217] * Mr.data()[158] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[173] * Mr.data()[234]) + Mr.data()
		[111] * Mr.data()[142] * Mr.data()[203] * Mr.data()[264]) + Mr.data()[111] * Mr.data()[142] * Mr.data()[218] * Mr.data()[249]) + Mr.data()
		[111] * Mr.data()[157] * Mr.data()[188] * Mr.data()[264]) + Mr.data()[111] * Mr.data()[157] * Mr.data()[203] * Mr.data()[249]) + Mr.data()
		[111] * Mr.data()[157] * Mr.data()[218] * Mr.data()[234]) + Mr.data()[111] * Mr.data()[172] * Mr.data()[188] * Mr.data()[249]) + Mr.data()
		[111] * Mr.data()[172] * Mr.data()[203] * Mr.data()[234]) - Mr.data()[111] * Mr.data()[187] * Mr.data()[158] * Mr.data()[264]) - Mr.data()
		[111] * Mr.data()[187] * Mr.data()[173] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[143] * Mr.data()[264]) - Mr.data()
		[111] * Mr.data()[202] * Mr.data()[158] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[173] * Mr.data()[234]) - Mr.data()
		[111] * Mr.data()[217] * Mr.data()[143] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[217] * Mr.data()[158] * Mr.data()[234]) + Mr.data()
		[126] * Mr.data()[142] * Mr.data()[188] * Mr.data()[264]) + Mr.data()[126] * Mr.data()[142] * Mr.data()[203] * Mr.data()[249]) + Mr.data()
		[126] * Mr.data()[142] * Mr.data()[218] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[157] * Mr.data()[188] * Mr.data()[249]) + Mr.data()
		[126] * Mr.data()[157] * Mr.data()[203] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[188] * Mr.data()[234]) - Mr.data()
		[126] * Mr.data()[187] * Mr.data()[143] * Mr.data()[264]) - Mr.data()[126] * Mr.data()[187] * Mr.data()[158] * Mr.data()[249]) - Mr.data()
		[126] * Mr.data()[187] * Mr.data()[173] * Mr.data()[234]) - Mr.data()[126] * Mr.data()[202] * Mr.data()[143] * Mr.data()[249]) - Mr.data()
		[126] * Mr.data()[202] * Mr.data()[158] * Mr.data()[234]) - Mr.data()[126] * Mr.data()[217] * Mr.data()[143] * Mr.data()[234]) - Mr.data()
		[141] * Mr.data()[97] * Mr.data()[218] * Mr.data()[264]) - Mr.data()[141] * Mr.data()[112] * Mr.data()[203] * Mr.data()[264]) - Mr.data()
		[141] * Mr.data()[112] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[127] * Mr.data()[188] * Mr.data()[264]) - Mr.data()
		[141] * Mr.data()[127] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[141] * Mr.data()[127] * Mr.data()[218] * Mr.data()[234]) + Mr.data()
		[141] * Mr.data()[187] * Mr.data()[128] * Mr.data()[264]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[113] * Mr.data()[264]) + Mr.data()
		[141] * Mr.data()[202] * Mr.data()[128] * Mr.data()[249]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[98] * Mr.data()[264]) + Mr.data()
		[141] * Mr.data()[217] * Mr.data()[113] * Mr.data()[249]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[128] * Mr.data()[234]) - Mr.data()
		[156] * Mr.data()[97] * Mr.data()[203] * Mr.data()[264]) - Mr.data()[156] * Mr.data()[97] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[156]
		* Mr.data()[112] * Mr.data()[188] * Mr.data()[264]) - Mr.data()[156] * Mr.data()[112] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[156] *
		Mr.data()[112] * Mr.data()[218] * Mr.data()[234]) - Mr.data()[156] * Mr.data()[127] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[156] * Mr.data()
		[127] * Mr.data()[203] * Mr.data()[234]) + Mr.data()[156] * Mr.data()[187] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[156] * Mr.data()
		[187] * Mr.data()[128] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[202] * Mr.data()[98] * Mr.data()[264]) + Mr.data()[156] * Mr.data()
		[202] * Mr.data()[113] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[202] * Mr.data()[128] * Mr.data()[234]) + Mr.data()[156] * Mr.data()
		[217] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[217] * Mr.data()[113] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[97]
		* Mr.data()[188] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[97] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[97] * Mr.data()
		[218] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[112] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[112] * Mr.data()
		[203] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[127] * Mr.data()[188] * Mr.data()[234]) + Mr.data()[171] * Mr.data()[187] * Mr.data()
		[98] * Mr.data()[264]) + Mr.data()[171] * Mr.data()[187] * Mr.data()[113] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[187] * Mr.data()
		[128] * Mr.data()[234]) + Mr.data()[171] * Mr.data()[202] * Mr.data()[98] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[202] * Mr.data()
		[113] * Mr.data()[234]) + Mr.data()[171] * Mr.data()[217] * Mr.data()[98] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[97] * Mr.data()[173]
		* Mr.data()[264]) + Mr.data()[186] * Mr.data()[112] * Mr.data()[158] * Mr.data()[264]) + Mr.data()[186] * Mr.data()[112] * Mr.data()[173] *
		Mr.data()[249]) + Mr.data()[186] * Mr.data()[127] * Mr.data()[143] * Mr.data()[264]) + Mr.data()[186] * Mr.data()[127] * Mr.data()[158] * Mr.data()
		[249]) + Mr.data()[186] * Mr.data()[127] * Mr.data()[173] * Mr.data()[234]) - Mr.data()[186] * Mr.data()[142] * Mr.data()[128] * Mr.data()
		[264]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[113] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[128] * Mr.data()
		[249]) - Mr.data()[186] * Mr.data()[172] * Mr.data()[98] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[172] * Mr.data()[113] * Mr.data()
		[249]) - Mr.data()[186] * Mr.data()[172] * Mr.data()[128] * Mr.data()[234]) + Mr.data()[201] * Mr.data()[97] * Mr.data()[158] * Mr.data()
		[264]) + Mr.data()[201] * Mr.data()[97] * Mr.data()[173] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[143] * Mr.data()
		[264]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[158] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[173] * Mr.data()
		[234]) + Mr.data()[201] * Mr.data()[127] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[127] * Mr.data()[158] * Mr.data()
		[234]) - Mr.data()[201] * Mr.data()[142] * Mr.data()[113] * Mr.data()[264]) - Mr.data()[201] * Mr.data()
		[142] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[201] * Mr.data()[157] * Mr.data()[98] * Mr.data()[264])
		- Mr.data()[201] * Mr.data()[157] * Mr.data()[113] * Mr.data()[249]) - Mr.data()[201] * Mr.data()[157] * Mr.data()
		[128] * Mr.data()[234]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[98] * Mr.data()[249]) - Mr.data()[201] *
		Mr.data()[172] * Mr.data()[113] * Mr.data()[234]) + Mr.data()[216] * Mr.data()[97] * Mr.data()[143] * Mr.data()[264]) +
		Mr.data()[216] * Mr.data()[97] * Mr.data()[158] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[97] * Mr.data()[173] * Mr.data()
		[234]) + Mr.data()[216] * Mr.data()[112] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[112] * Mr.data()
		[158] * Mr.data()[234]) + Mr.data()[216] * Mr.data()[127] * Mr.data()[143] * Mr.data()[234]) - Mr.data()[216] * Mr.data()[142]
		* Mr.data()[98] * Mr.data()[264]) - Mr.data()[216] * Mr.data()[142] * Mr.data()[113] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[142]
		* Mr.data()[128] * Mr.data()[234]) - Mr.data()[216] * Mr.data()[157] * Mr.data()[98] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[157] *
		Mr.data()[113] * Mr.data()[234]) - Mr.data()[216] * Mr.data()[172] * Mr.data()[98] * Mr.data()[234];
	cq[5] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((Mr.data()
		[97] * Mr.data()[203] * Mr.data()[174] * Mr.data()[261] - Mr.data()[97] * Mr.data()[173] * Mr.data()[204] * Mr.data()[261]) - Mr.data()[97] *
		Mr.data()[173] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[97] * Mr.data()[158] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[97] * Mr.data()
		[218] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[97] * Mr.data()[218] * Mr.data()[174] * Mr.data()[246]) - Mr.data()[112] * Mr.data()
		[143] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[112] * Mr.data()[158] * Mr.data()[204] * Mr.data()[261]) - Mr.data()[112] * Mr.data()
		[158] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[173] * Mr.data()[189] * Mr.data()[261]) - Mr.data()[112] * Mr.data()
		[173] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[112] * Mr.data()[173] * Mr.data()[219] * Mr.data()[231]) + Mr.data()[112] * Mr.data()
		[188] * Mr.data()[174] * Mr.data()[261]) + Mr.data()[112] * Mr.data()[203] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[112] * Mr.data()
		[203] * Mr.data()[174] * Mr.data()[246]) + Mr.data()[112] * Mr.data()[218] * Mr.data()[144] * Mr.data()[261]) + Mr.data()[112] * Mr.data()
		[218] * Mr.data()[159] * Mr.data()[246]) + Mr.data()[112] * Mr.data()[218] * Mr.data()[174] * Mr.data()[231]) - Mr.data()[127] * Mr.data()
		[143] * Mr.data()[204] * Mr.data()[261]) - Mr.data()[127] * Mr.data()[143] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[127] * Mr.data()
		[158] * Mr.data()[189] * Mr.data()[261]) - Mr.data()[127] * Mr.data()[158] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[127] * Mr.data()
		[158] * Mr.data()[219] * Mr.data()[231]) - Mr.data()[127] * Mr.data()[173] * Mr.data()[189] * Mr.data()[246]) - Mr.data()[127] * Mr.data()
		[173] * Mr.data()[204] * Mr.data()[231]) + Mr.data()[127] * Mr.data()[188] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[127] * Mr.data()
		[188] * Mr.data()[174] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[203] * Mr.data()[144] * Mr.data()[261]) + Mr.data()[127] * Mr.data()
		[203] * Mr.data()[159] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[203] * Mr.data()[174] * Mr.data()[231]) + Mr.data()[127] * Mr.data()
		[218] * Mr.data()[144] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[218] * Mr.data()[159] * Mr.data()[231]) + Mr.data()[142] * Mr.data()
		[113] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[142] * Mr.data()[128] * Mr.data()[204] * Mr.data()[261]) + Mr.data()[142] * Mr.data()
		[128] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[142] * Mr.data()[203] * Mr.data()[129] * Mr.data()[261]) - Mr.data()[142] * Mr.data()
		[218] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[142] * Mr.data()[218] * Mr.data()[129] * Mr.data()[246]) + Mr.data()[157] * Mr.data()
		[98] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[157] * Mr.data()[113] * Mr.data()[204] * Mr.data()[261]) + Mr.data()[157] * Mr.data()
		[113] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[128] * Mr.data()[189] * Mr.data()[261]) + Mr.data()[157] * Mr.data()
		[128] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[157] * Mr.data()[128] * Mr.data()[219] * Mr.data()[231]) - Mr.data()[157] * Mr.data()
		[188] * Mr.data()[129] * Mr.data()[261]) - Mr.data()[157] * Mr.data()[203] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[157] * Mr.data()
		[203] * Mr.data()[129] * Mr.data()[246]) - Mr.data()[157] * Mr.data()[218] * Mr.data()[99] * Mr.data()[261]) - Mr.data()[157] * Mr.data()
		[218] * Mr.data()[114] * Mr.data()[246]) - Mr.data()[157] * Mr.data()[218] * Mr.data()[129] * Mr.data()[231]) + Mr.data()[172] * Mr.data()
		[98] * Mr.data()[204] * Mr.data()[261]) + Mr.data()[172] * Mr.data()[98] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[113]
		* Mr.data()[189] * Mr.data()[261]) + Mr.data()[172] * Mr.data()[113] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[113] *
		Mr.data()[219] * Mr.data()[231]) + Mr.data()[172] * Mr.data()[128] * Mr.data()[189] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[128] * Mr.data()
		[204] * Mr.data()[231]) - Mr.data()[172] * Mr.data()[188] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[172] * Mr.data()[188] * Mr.data()
		[129] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[203] * Mr.data()[99] * Mr.data()[261]) - Mr.data()[172] * Mr.data()[203] * Mr.data()
		[114] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[203] * Mr.data()[129] * Mr.data()[231]) - Mr.data()[172] * Mr.data()[218] * Mr.data()
		[99] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[218] * Mr.data()[114] * Mr.data()[231]) - Mr.data()[187] * Mr.data()[113] * Mr.data()
		[174] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[128] * Mr.data()[159] * Mr.data()[261]) - Mr.data()[187] * Mr.data()[128] * Mr.data()
		[174] * Mr.data()[246]) + Mr.data()[187] * Mr.data()[158] * Mr.data()[129] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[173] * Mr.data()
		[114] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[173] * Mr.data()[129] * Mr.data()[246]) - Mr.data()[202] * Mr.data()[98] * Mr.data()
		[174] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[113] * Mr.data()[159] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[113] * Mr.data()
		[174] * Mr.data()[246]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[144] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[128] * Mr.data()
		[159] * Mr.data()[246]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[174] * Mr.data()[231]) + Mr.data()[202] * Mr.data()[143] * Mr.data()
		[129] * Mr.data()[261]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[114] * Mr.data()[261]) + Mr.data()[202] * Mr.data()[158] * Mr.data()
		[129] * Mr.data()[246]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[99] * Mr.data()[261]) + Mr.data()[202] * Mr.data()[173] * Mr.data()
		[114] * Mr.data()[246]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[129] * Mr.data()[231]) - Mr.data()[217] * Mr.data()[98] * Mr.data()
		[159] * Mr.data()[261]) - Mr.data()[217] * Mr.data()[98] * Mr.data()[174] * Mr.data()[246]) - Mr.data()[217] * Mr.data()[113] * Mr.data()
		[144] * Mr.data()[261]) - Mr.data()[217] * Mr.data()[113] * Mr.data()[159] * Mr.data()[246]) - Mr.data()[217] * Mr.data()[113] * Mr.data()
		[174] * Mr.data()[231]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[144] * Mr.data()[246]) - Mr.data()[217] * Mr.data()[128] * Mr.data()
		[159] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[143] * Mr.data()[114] * Mr.data()[261]) + Mr.data()[217] * Mr.data()[143] * Mr.data()
		[129] * Mr.data()[246]) + Mr.data()[217] * Mr.data()[158] * Mr.data()[99] * Mr.data()[261]) + Mr.data()[217] * Mr.data()[158] * Mr.data()
		[114] * Mr.data()[246]) + Mr.data()[217] * Mr.data()[158] * Mr.data()[129] * Mr.data()[231]) + Mr.data()[217] * Mr.data()[173] * Mr.data()
		[99] * Mr.data()[246]) + Mr.data()[217] * Mr.data()[173] * Mr.data()[114] * Mr.data()[231]) + Mr.data()[96] * Mr.data()[158] * Mr.data()[219]
		* Mr.data()[262]) + Mr.data()[96] * Mr.data()[173] * Mr.data()[204] * Mr.data()[262]) + Mr.data()[96] * Mr.data()[173] * Mr.data()[219] * Mr.data()
		[247]) - Mr.data()[96] * Mr.data()[203] * Mr.data()[174] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[159] * Mr.data()[262])
		- Mr.data()[96] * Mr.data()[218] * Mr.data()[174] * Mr.data()[247]) + Mr.data()[111] * Mr.data()[143] * Mr.data()[219] * Mr.data()[262]) +
		Mr.data()[111] * Mr.data()[158] * Mr.data()[204] * Mr.data()[262]) + Mr.data()[111] * Mr.data()[158] * Mr.data()[219] * Mr.data()[247]) + Mr.data()
		[111] * Mr.data()[173] * Mr.data()[189] * Mr.data()[262]) + Mr.data()[111] * Mr.data()[173] * Mr.data()[204] * Mr.data()[247]) + Mr.data()
		[111] * Mr.data()[173] * Mr.data()[219] * Mr.data()[232]) - Mr.data()[111] * Mr.data()[188] * Mr.data()[174] * Mr.data()[262]) - Mr.data()
		[111] * Mr.data()[203] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[174] * Mr.data()[247]) - Mr.data()
		[111] * Mr.data()[218] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[111] * Mr.data()[218] * Mr.data()[159] * Mr.data()[247]) - Mr.data()
		[111] * Mr.data()[218] * Mr.data()[174] * Mr.data()[232]) + Mr.data()[126] * Mr.data()[143] * Mr.data()[204] * Mr.data()[262]) + Mr.data()
		[126] * Mr.data()[143] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[189] * Mr.data()[262]) + Mr.data()
		[126] * Mr.data()[158] * Mr.data()[204] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[219] * Mr.data()[232]) + Mr.data()
		[126] * Mr.data()[173] * Mr.data()[189] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[204] * Mr.data()[232]) - Mr.data()
		[126] * Mr.data()[188] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[126] * Mr.data()[188] * Mr.data()[174] * Mr.data()[247]) - Mr.data()
		[126] * Mr.data()[203] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[126] * Mr.data()[203] * Mr.data()[159] * Mr.data()[247]) - Mr.data()
		[126] * Mr.data()[203] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[126] * Mr.data()[218] * Mr.data()[144] * Mr.data()[247]) - Mr.data()
		[126] * Mr.data()[218] * Mr.data()[159] * Mr.data()[232]) - Mr.data()[141] * Mr.data()[113] * Mr.data()[219] * Mr.data()[262]) - Mr.data()
		[141] * Mr.data()[128] * Mr.data()[204] * Mr.data()[262]) - Mr.data()[141] * Mr.data()[128] * Mr.data()[219] * Mr.data()[247]) + Mr.data()
		[141] * Mr.data()[203] * Mr.data()[129] * Mr.data()[262]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[114] * Mr.data()[262]) + Mr.data()
		[141] * Mr.data()[218] * Mr.data()[129] * Mr.data()[247]) - Mr.data()[156] * Mr.data()[98] * Mr.data()[219] * Mr.data()[262]) - Mr.data()
		[156] * Mr.data()[113] * Mr.data()[204] * Mr.data()[262]) - Mr.data()[156] * Mr.data()[113] * Mr.data()[219] * Mr.data()[247]) - Mr.data()
		[156] * Mr.data()[128] * Mr.data()[189] * Mr.data()[262]) - Mr.data()[156] * Mr.data()[128] * Mr.data()[204] * Mr.data()[247]) - Mr.data()
		[156] * Mr.data()[128] * Mr.data()[219] * Mr.data()[232]) + Mr.data()[156] * Mr.data()[188] * Mr.data()[129] * Mr.data()[262]) + Mr.data()
		[156] * Mr.data()[203] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[156] * Mr.data()[203] * Mr.data()[129] * Mr.data()[247]) + Mr.data()
		[156] * Mr.data()[218] * Mr.data()[99] * Mr.data()[262]) + Mr.data()[156] * Mr.data()[218] * Mr.data()[114] * Mr.data()[247]) + Mr.data()
		[156] * Mr.data()[218] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[171] * Mr.data()[98] * Mr.data()[204] * Mr.data()[262]) - Mr.data()
		[171] * Mr.data()[98] * Mr.data()[219] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[113] * Mr.data()[189] * Mr.data()[262]) - Mr.data()
		[171] * Mr.data()[113] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[113] * Mr.data()[219] * Mr.data()[232]) - Mr.data()
		[171] * Mr.data()[128] * Mr.data()[189] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[128] * Mr.data()[204] * Mr.data()[232]) + Mr.data()
		[171] * Mr.data()[188] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[171] * Mr.data()[188] * Mr.data()[129] * Mr.data()[247]) + Mr.data()
		[171] * Mr.data()[203] * Mr.data()[99] * Mr.data()[262]) + Mr.data()[171] * Mr.data()[203] * Mr.data()[114] * Mr.data()[247]) + Mr.data()
		[171] * Mr.data()[203] * Mr.data()[129] * Mr.data()[232]) + Mr.data()[171] * Mr.data()[218] * Mr.data()[99] * Mr.data()[247]) + Mr.data()
		[171] * Mr.data()[218] * Mr.data()[114] * Mr.data()[232]) + Mr.data()[186] * Mr.data()[113] * Mr.data()[174] * Mr.data()[262]) + Mr.data()
		[186] * Mr.data()[128] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[186] * Mr.data()[128] * Mr.data()[174] * Mr.data()[247]) - Mr.data()
		[186] * Mr.data()[158] * Mr.data()[129] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[173] * Mr.data()[114] * Mr.data()[262]) - Mr.data()
		[186] * Mr.data()[173] * Mr.data()[129] * Mr.data()[247]) + Mr.data()[201] * Mr.data()[98] * Mr.data()[174] * Mr.data()[262]) + Mr.data()
		[201] * Mr.data()[113] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[201] * Mr.data()[113] * Mr.data()[174] * Mr.data()[247]) + Mr.data()
		[201] * Mr.data()[128] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[201] * Mr.data()[128] * Mr.data()[159] * Mr.data()[247]) + Mr.data()
		[201] * Mr.data()[128] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[201] * Mr.data()[143] * Mr.data()[129] * Mr.data()[262]) - Mr.data()
		[201] * Mr.data()[158] * Mr.data()[114] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[158] * Mr.data()[129] * Mr.data()[247]) - Mr.data()
		[201] * Mr.data()[173] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[173] * Mr.data()[114] * Mr.data()[247]) - Mr.data()
		[201] * Mr.data()[173] * Mr.data()[129] * Mr.data()[232]) + Mr.data()[216] * Mr.data()[98] * Mr.data()[159] * Mr.data()[262]) + Mr.data()
		[216] * Mr.data()[98] * Mr.data()[174] * Mr.data()[247]) + Mr.data()[216] * Mr.data()[113] * Mr.data()[144] * Mr.data()[262]) + Mr.data()
		[216] * Mr.data()[113] * Mr.data()[159] * Mr.data()[247]) + Mr.data()[216] * Mr.data()[113] * Mr.data()[174] * Mr.data()[232]) + Mr.data()
		[216] * Mr.data()[128] * Mr.data()[144] * Mr.data()[247]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[159] * Mr.data()[232]) - Mr.data()
		[216] * Mr.data()[143] * Mr.data()[114] * Mr.data()[262]) - Mr.data()[216] * Mr.data()[143] * Mr.data()[129] * Mr.data()[247]) - Mr.data()
		[216] * Mr.data()[158] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[216] * Mr.data()[158] * Mr.data()[114] * Mr.data()[247]) - Mr.data()
		[216] * Mr.data()[158] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[99] * Mr.data()[247]) - Mr.data()
		[216] * Mr.data()[173] * Mr.data()[114] * Mr.data()[232]) - Mr.data()[96] * Mr.data()[157] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[96]
		* Mr.data()[172] * Mr.data()[204] * Mr.data()[263]) - Mr.data()[96] * Mr.data()[172] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[96] * Mr.data()
		[202] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[217]
		* Mr.data()[174] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[142] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[111] * Mr.data()[157] *
		Mr.data()[204] * Mr.data()[263]) - Mr.data()[111] * Mr.data()[157] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[172] * Mr.data()
		[189] * Mr.data()[263]) - Mr.data()[111] * Mr.data()[172] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[111] * Mr.data()[172] * Mr.data()
		[219] * Mr.data()[233]) + Mr.data()[111] * Mr.data()[187] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[202] * Mr.data()
		[159] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[217] * Mr.data()
		[144] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[217] * Mr.data()[159] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[217] * Mr.data()
		[174] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[142] * Mr.data()[204] * Mr.data()[263]) - Mr.data()[126] * Mr.data()[142] * Mr.data()
		[219] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[157] * Mr.data()[189] * Mr.data()[263]) - Mr.data()[126] * Mr.data()[157] * Mr.data()
		[204] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[157] * Mr.data()[219] * Mr.data()[233]) - Mr.data()[126] * Mr.data()[172] * Mr.data()
		[189] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[172] * Mr.data()[204] * Mr.data()[233]) + Mr.data()[126] * Mr.data()[187] * Mr.data()
		[159] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[187] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[202] * Mr.data()
		[144] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[202] * Mr.data()[159] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[202] * Mr.data()
		[174] * Mr.data()[233]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[144] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[217] * Mr.data()
		[159] * Mr.data()[233]) + Mr.data()[141] * Mr.data()[112] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[141] * Mr.data()[127] * Mr.data()
		[204] * Mr.data()[263]) + Mr.data()[141] * Mr.data()[127] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[141] * Mr.data()[202] * Mr.data()
		[129] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[217] * Mr.data()
		[129] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[97] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[156] * Mr.data()[112] * Mr.data()
		[204] * Mr.data()[263]) + Mr.data()[156] * Mr.data()[112] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[127] * Mr.data()
		[189] * Mr.data()[263]) + Mr.data()[156] * Mr.data()[127] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[156] * Mr.data()[127] * Mr.data()
		[219] * Mr.data()[233]) - Mr.data()[156] * Mr.data()[187] * Mr.data()[129] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[202] * Mr.data()
		[114] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[202] * Mr.data()[129] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[217] * Mr.data()
		[99] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[217] * Mr.data()[114] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[217] * Mr.data()
		[129] * Mr.data()[233]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[204] * Mr.data()[263]) + Mr.data()[171] * Mr.data()[97] * Mr.data()[219]
		* Mr.data()[248]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[189] * Mr.data()[263]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[204] *
		Mr.data()[248]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[219] * Mr.data()[233]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[189] * Mr.data()
		[248]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[204] * Mr.data()[233]) - Mr.data()[171] * Mr.data()[187] * Mr.data()[114] * Mr.data()
		[263]) - Mr.data()[171] * Mr.data()[187] * Mr.data()[129] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[99] * Mr.data()
		[263]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[114] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[129] * Mr.data()
		[233]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[99] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[114] * Mr.data()
		[233]) - Mr.data()[186] * Mr.data()[112] * Mr.data()[174] * Mr.data()[263]) - Mr.data()[186] * Mr.data()[127] * Mr.data()[159] * Mr.data()
		[263]) - Mr.data()[186] * Mr.data()[127] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[186] * Mr.data()[157] * Mr.data()[129] * Mr.data()
		[263]) + Mr.data()[186] * Mr.data()[172] * Mr.data()[114] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[172] * Mr.data()[129] * Mr.data()
		[248]) - Mr.data()[201] * Mr.data()[97] * Mr.data()[174] * Mr.data()[263]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[159] * Mr.data()
		[263]) - Mr.data()[201] * Mr.data()[112] * Mr.data()[174] * Mr.data()[248]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[144] * Mr.data()
		[263]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[159] * Mr.data()[248]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[174] * Mr.data()
		[233]) + Mr.data()[201] * Mr.data()[142] * Mr.data()[129] * Mr.data()[263]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[114] * Mr.data()
		[263]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[129] * Mr.data()[248]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[99] * Mr.data()
		[263]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[114] * Mr.data()[248]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[129] * Mr.data()
		[233]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[159] * Mr.data()[263]) - Mr.data()[216] * Mr.data()[97] * Mr.data()[174] * Mr.data()[248])
		- Mr.data()[216] * Mr.data()[112] * Mr.data()[144] * Mr.data()[263]) - Mr.data()[216] * Mr.data()[112] * Mr.data()[159] * Mr.data()[248]) -
		Mr.data()[216] * Mr.data()[112] * Mr.data()[174] * Mr.data()[233]) - Mr.data()[216] * Mr.data()[127] * Mr.data()[144] * Mr.data()[248]) - Mr.data()
		[216] * Mr.data()[127] * Mr.data()[159] * Mr.data()[233]) + Mr.data()[216] * Mr.data()[142] * Mr.data()[114] * Mr.data()[263]) + Mr.data()
		[216] * Mr.data()[142] * Mr.data()[129] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[157] * Mr.data()[99] * Mr.data()[263]) + Mr.data()
		[216] * Mr.data()[157] * Mr.data()[114] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[157] * Mr.data()[129] * Mr.data()[233]) + Mr.data()
		[216] * Mr.data()[172] * Mr.data()[99] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[172] * Mr.data()[114] * Mr.data()[233]) + Mr.data()[96]
		* Mr.data()[157] * Mr.data()[218] * Mr.data()[264]) + Mr.data()[96] * Mr.data()[172] * Mr.data()[203] * Mr.data()[264]) + Mr.data()[96] * Mr.data()
		[172] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[96] * Mr.data()[202] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[217]
		* Mr.data()[158] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[173] * Mr.data()[249]) + Mr.data()[111] * Mr.data()[142] *
		Mr.data()[218] * Mr.data()[264]) + Mr.data()[111] * Mr.data()[157] * Mr.data()[203] * Mr.data()[264]) + Mr.data()[111] * Mr.data()[157] * Mr.data()
		[218] * Mr.data()[249]) + Mr.data()[111] * Mr.data()[172] * Mr.data()[188] * Mr.data()[264]) + Mr.data()[111] * Mr.data()[172] * Mr.data()
		[203] * Mr.data()[249]) + Mr.data()[111] * Mr.data()[172] * Mr.data()[218] * Mr.data()[234]) - Mr.data()[111] * Mr.data()[187] * Mr.data()
		[173] * Mr.data()[264]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[158] * Mr.data()[264]) - Mr.data()[111] * Mr.data()[202] * Mr.data()
		[173] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[217] * Mr.data()[143] * Mr.data()[264]) - Mr.data()[111] * Mr.data()[217] * Mr.data()
		[158] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[217] * Mr.data()[173] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[142] * Mr.data()
		[203] * Mr.data()[264]) + Mr.data()[126] * Mr.data()[142] * Mr.data()[218] * Mr.data()[249]) + Mr.data()[126] * Mr.data()[157] * Mr.data()
		[188] * Mr.data()[264]) + Mr.data()[126] * Mr.data()[157] * Mr.data()[203] * Mr.data()[249]) + Mr.data()[126] * Mr.data()[157] * Mr.data()
		[218] * Mr.data()[234]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[188] * Mr.data()[249]) + Mr.data()[126] * Mr.data()[172] * Mr.data()
		[203] * Mr.data()[234]) - Mr.data()[126] * Mr.data()[187] * Mr.data()[158] * Mr.data()[264]) - Mr.data()[126] * Mr.data()[187] * Mr.data()
		[173] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[202] * Mr.data()[143] * Mr.data()[264]) - Mr.data()[126] * Mr.data()[202] * Mr.data()
		[158] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[202] * Mr.data()[173] * Mr.data()[234]) - Mr.data()[126] * Mr.data()[217] * Mr.data()
		[143] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[217] * Mr.data()[158] * Mr.data()[234]) - Mr.data()[141] * Mr.data()[112] * Mr.data()
		[218] * Mr.data()[264]) - Mr.data()[141] * Mr.data()[127] * Mr.data()[203] * Mr.data()[264]) - Mr.data()[141] * Mr.data()[127] * Mr.data()
		[218] * Mr.data()[249]) + Mr.data()[141] * Mr.data()[202] * Mr.data()[128] * Mr.data()[264]) + Mr.data()[141] * Mr.data()[217] * Mr.data()
		[113] * Mr.data()[264]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[156] * Mr.data()[97] * Mr.data()
		[218] * Mr.data()[264]) - Mr.data()[156] * Mr.data()[112] * Mr.data()[203] * Mr.data()[264]) - Mr.data()[156] * Mr.data()[112] * Mr.data()
		[218] * Mr.data()[249]) - Mr.data()[156] * Mr.data()[127] * Mr.data()[188] * Mr.data()[264]) - Mr.data()[156] * Mr.data()[127] * Mr.data()
		[203] * Mr.data()[249]) - Mr.data()[156] * Mr.data()[127] * Mr.data()[218] * Mr.data()[234]) + Mr.data()[156] * Mr.data()[187] * Mr.data()
		[128] * Mr.data()[264]) + Mr.data()[156] * Mr.data()[202] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[156] * Mr.data()[202] * Mr.data()
		[128] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[217] * Mr.data()[98] * Mr.data()[264]) + Mr.data()[156] * Mr.data()[217] * Mr.data()
		[113] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[217] * Mr.data()[128] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[97] * Mr.data()
		[203] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[97] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[112] * Mr.data()
		[188] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[112] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[112] * Mr.data()
		[218] * Mr.data()[234]) - Mr.data()[171] * Mr.data()[127] * Mr.data()[188] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[127] * Mr.data()
		[203] * Mr.data()[234]) + Mr.data()[171] * Mr.data()[187] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[171] * Mr.data()[187] * Mr.data()
		[128] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[202] * Mr.data()[98] * Mr.data()[264]) + Mr.data()[171] * Mr.data()[202] * Mr.data()
		[113] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[202] * Mr.data()[128] * Mr.data()[234]) + Mr.data()[171] * Mr.data()[217] * Mr.data()
		[98] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[217] * Mr.data()[113] * Mr.data()[234]) + Mr.data()[186] * Mr.data()[112] * Mr.data()
		[173] * Mr.data()[264]) + Mr.data()[186] * Mr.data()[127] * Mr.data()[158] * Mr.data()[264]) + Mr.data()[186] * Mr.data()[127] * Mr.data()
		[173] * Mr.data()[249]) - Mr.data()[186] * Mr.data()[157] * Mr.data()[128] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[172] * Mr.data()
		[113] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[172] * Mr.data()[128] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[97] * Mr.data()
		[173] * Mr.data()[264]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[158] * Mr.data()[264]) + Mr.data()[201] * Mr.data()[112] * Mr.data()
		[173] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[127] * Mr.data()[143] * Mr.data()[264]) + Mr.data()[201] * Mr.data()[127] * Mr.data()
		[158] * Mr.data()[249]) + Mr.data()[201] * Mr.data()[127] * Mr.data()[173] * Mr.data()[234]) - Mr.data()[201] * Mr.data()[142] * Mr.data()
		[128] * Mr.data()[264]) - Mr.data()[201] * Mr.data()[157] * Mr.data()[113] * Mr.data()[264]) - Mr.data()
		[201] * Mr.data()[157] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[98]
		* Mr.data()[264]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[113] * Mr.data()[249]) - Mr.data()[201] * Mr.data()
		[172] * Mr.data()[128] * Mr.data()[234]) + Mr.data()[216] * Mr.data()[97] * Mr.data()[158] * Mr.data()[264]) +
		Mr.data()[216] * Mr.data()[97] * Mr.data()[173] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[112] * Mr.data()[143] *
		Mr.data()[264]) + Mr.data()[216] * Mr.data()[112] * Mr.data()[158] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[112] *
		Mr.data()[173] * Mr.data()[234]) + Mr.data()[216] * Mr.data()[127] * Mr.data()[143] * Mr.data()[249]) + Mr.data()[216] * Mr.data()
		[127] * Mr.data()[158] * Mr.data()[234]) - Mr.data()[216] * Mr.data()[142] * Mr.data()[113] * Mr.data()[264]) - Mr.data()[216]
		* Mr.data()[142] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[157] * Mr.data()[98] * Mr.data()[264]) - Mr.data()[216]
		* Mr.data()[157] * Mr.data()[113] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[157] * Mr.data()[128] * Mr.data()[234]) - Mr.data()[216]
		* Mr.data()[172] * Mr.data()[98] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[172] * Mr.data()[113] * Mr.data()[234];
	cq[6] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((Mr.data()[97] * Mr.data()[218] * Mr.data()[174] * Mr.data()[261] - Mr.data()[97] * Mr.data()[173] * Mr.data()[219] * Mr.data()[261])
		- Mr.data()[112] * Mr.data()[158] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[112] * Mr.data()[173] * Mr.data()[204] * Mr.data()[261]) -
		Mr.data()[112] * Mr.data()[173] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[112] * Mr.data()[203] * Mr.data()[174] * Mr.data()[261]) + Mr.data()
		[112] * Mr.data()[218] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[112] * Mr.data()[218] * Mr.data()[174] * Mr.data()[246]) - Mr.data()
		[127] * Mr.data()[143] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[127] * Mr.data()[158] * Mr.data()[204] * Mr.data()[261]) - Mr.data()
		[127] * Mr.data()[158] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[127] * Mr.data()[173] * Mr.data()[189] * Mr.data()[261]) - Mr.data()
		[127] * Mr.data()[173] * Mr.data()[204] * Mr.data()[246]) - Mr.data()[127] * Mr.data()[173] * Mr.data()[219] * Mr.data()[231]) + Mr.data()
		[127] * Mr.data()[188] * Mr.data()[174] * Mr.data()[261]) + Mr.data()[127] * Mr.data()[203] * Mr.data()[159] * Mr.data()[261]) + Mr.data()
		[127] * Mr.data()[203] * Mr.data()[174] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[218] * Mr.data()[144] * Mr.data()[261]) + Mr.data()
		[127] * Mr.data()[218] * Mr.data()[159] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[218] * Mr.data()[174] * Mr.data()[231]) + Mr.data()
		[142] * Mr.data()[128] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[142] * Mr.data()[218] * Mr.data()[129] * Mr.data()[261]) + Mr.data()
		[157] * Mr.data()[113] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[157] * Mr.data()[128] * Mr.data()[204] * Mr.data()[261]) + Mr.data()
		[157] * Mr.data()[128] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[157] * Mr.data()[203] * Mr.data()[129] * Mr.data()[261]) - Mr.data()
		[157] * Mr.data()[218] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[157] * Mr.data()[218] * Mr.data()[129] * Mr.data()[246]) + Mr.data()
		[172] * Mr.data()[98] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[172] * Mr.data()[113] * Mr.data()[204] * Mr.data()[261]) + Mr.data()
		[172] * Mr.data()[113] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[128] * Mr.data()[189] * Mr.data()[261]) + Mr.data()
		[172] * Mr.data()[128] * Mr.data()[204] * Mr.data()[246]) + Mr.data()[172] * Mr.data()[128] * Mr.data()[219] * Mr.data()[231]) - Mr.data()
		[172] * Mr.data()[188] * Mr.data()[129] * Mr.data()[261]) - Mr.data()[172] * Mr.data()[203] * Mr.data()[114] * Mr.data()[261]) - Mr.data()
		[172] * Mr.data()[203] * Mr.data()[129] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[218] * Mr.data()[99] * Mr.data()[261]) - Mr.data()
		[172] * Mr.data()[218] * Mr.data()[114] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[218] * Mr.data()[129] * Mr.data()[231]) - Mr.data()
		[187] * Mr.data()[128] * Mr.data()[174] * Mr.data()[261]) + Mr.data()[187] * Mr.data()[173] * Mr.data()[129] * Mr.data()[261]) - Mr.data()
		[202] * Mr.data()[113] * Mr.data()[174] * Mr.data()[261]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[159] * Mr.data()[261]) - Mr.data()
		[202] * Mr.data()[128] * Mr.data()[174] * Mr.data()[246]) + Mr.data()[202] * Mr.data()[158] * Mr.data()[129] * Mr.data()[261]) + Mr.data()
		[202] * Mr.data()[173] * Mr.data()[114] * Mr.data()[261]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[129] * Mr.data()[246]) - Mr.data()
		[217] * Mr.data()[98] * Mr.data()[174] * Mr.data()[261]) - Mr.data()[217] * Mr.data()[113] * Mr.data()[159] * Mr.data()[261]) - Mr.data()
		[217] * Mr.data()[113] * Mr.data()[174] * Mr.data()[246]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[144] * Mr.data()[261]) - Mr.data()
		[217] * Mr.data()[128] * Mr.data()[159] * Mr.data()[246]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[174] * Mr.data()[231]) + Mr.data()
		[217] * Mr.data()[143] * Mr.data()[129] * Mr.data()[261]) + Mr.data()[217] * Mr.data()[158] * Mr.data()[114] * Mr.data()[261]) + Mr.data()
		[217] * Mr.data()[158] * Mr.data()[129] * Mr.data()[246]) + Mr.data()[217] * Mr.data()[173] * Mr.data()[99] * Mr.data()[261]) + Mr.data()
		[217] * Mr.data()[173] * Mr.data()[114] * Mr.data()[246]) + Mr.data()[217] * Mr.data()[173] * Mr.data()[129] * Mr.data()[231]) + Mr.data()
		[96] * Mr.data()[173] * Mr.data()[219] * Mr.data()[262]) - Mr.data()[96] * Mr.data()[218] * Mr.data()[174] * Mr.data()[262]) + Mr.data()[111]
		* Mr.data()[158] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[111] * Mr.data()[173] * Mr.data()[204] * Mr.data()[262]) + Mr.data()[111] *
		Mr.data()[173] * Mr.data()[219] * Mr.data()[247]) - Mr.data()[111] * Mr.data()[203] * Mr.data()[174] * Mr.data()[262]) - Mr.data()[111] * Mr.data()
		[218] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[111] * Mr.data()[218] * Mr.data()[174] * Mr.data()[247]) + Mr.data()[126] * Mr.data()
		[143] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[204] * Mr.data()[262]) + Mr.data()[126] * Mr.data()
		[158] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[189] * Mr.data()[262]) + Mr.data()[126] * Mr.data()
		[173] * Mr.data()[204] * Mr.data()[247]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[219] * Mr.data()[232]) - Mr.data()[126] * Mr.data()
		[188] * Mr.data()[174] * Mr.data()[262]) - Mr.data()[126] * Mr.data()[203] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[126] * Mr.data()
		[203] * Mr.data()[174] * Mr.data()[247]) - Mr.data()[126] * Mr.data()[218] * Mr.data()[144] * Mr.data()[262]) - Mr.data()[126] * Mr.data()
		[218] * Mr.data()[159] * Mr.data()[247]) - Mr.data()[126] * Mr.data()[218] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[141] * Mr.data()
		[128] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[141] * Mr.data()[218] * Mr.data()[129] * Mr.data()[262]) - Mr.data()[156] * Mr.data()
		[113] * Mr.data()[219] * Mr.data()[262]) - Mr.data()[156] * Mr.data()[128] * Mr.data()[204] * Mr.data()[262]) - Mr.data()[156] * Mr.data()
		[128] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[156] * Mr.data()[203] * Mr.data()[129] * Mr.data()[262]) + Mr.data()[156] * Mr.data()
		[218] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[156] * Mr.data()[218] * Mr.data()[129] * Mr.data()[247]) - Mr.data()[171] * Mr.data()
		[98] * Mr.data()[219] * Mr.data()[262]) - Mr.data()[171] * Mr.data()[113] * Mr.data()[204] * Mr.data()[262]) - Mr.data()[171] * Mr.data()
		[113] * Mr.data()[219] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[128] * Mr.data()[189] * Mr.data()[262]) - Mr.data()[171] * Mr.data()
		[128] * Mr.data()[204] * Mr.data()[247]) - Mr.data()[171] * Mr.data()[128] * Mr.data()[219] * Mr.data()[232]) + Mr.data()[171] * Mr.data()
		[188] * Mr.data()[129] * Mr.data()[262]) + Mr.data()[171] * Mr.data()[203] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[171] * Mr.data()
		[203] * Mr.data()[129] * Mr.data()[247]) + Mr.data()[171] * Mr.data()[218] * Mr.data()[99] * Mr.data()[262]) + Mr.data()[171] * Mr.data()
		[218] * Mr.data()[114] * Mr.data()[247]) + Mr.data()[171] * Mr.data()[218] * Mr.data()[129] * Mr.data()[232]) + Mr.data()[186] * Mr.data()
		[128] * Mr.data()[174] * Mr.data()[262]) - Mr.data()[186] * Mr.data()[173] * Mr.data()[129] * Mr.data()[262]) + Mr.data()[201] * Mr.data()
		[113] * Mr.data()[174] * Mr.data()[262]) + Mr.data()[201] * Mr.data()[128] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[201] * Mr.data()
		[128] * Mr.data()[174] * Mr.data()[247]) - Mr.data()[201] * Mr.data()[158] * Mr.data()[129] * Mr.data()[262]) - Mr.data()[201] * Mr.data()
		[173] * Mr.data()[114] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[173] * Mr.data()[129] * Mr.data()[247]) + Mr.data()[216] * Mr.data()
		[98] * Mr.data()[174] * Mr.data()[262]) + Mr.data()[216] * Mr.data()[113] * Mr.data()[159] * Mr.data()[262]) + Mr.data()[216] * Mr.data()
		[113] * Mr.data()[174] * Mr.data()[247]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[144] * Mr.data()[262]) + Mr.data()[216] * Mr.data()
		[128] * Mr.data()[159] * Mr.data()[247]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[174] * Mr.data()[232]) - Mr.data()[216] * Mr.data()
		[143] * Mr.data()[129] * Mr.data()[262]) - Mr.data()[216] * Mr.data()[158] * Mr.data()[114] * Mr.data()[262]) - Mr.data()[216] * Mr.data()
		[158] * Mr.data()[129] * Mr.data()[247]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[99] * Mr.data()[262]) - Mr.data()[216] * Mr.data()
		[173] * Mr.data()[114] * Mr.data()[247]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[129] * Mr.data()[232]) - Mr.data()[96] * Mr.data()
		[172] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[96] * Mr.data()[217] * Mr.data()[174] * Mr.data()[263]) - Mr.data()[111] * Mr.data()
		[157] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[111] * Mr.data()[172] * Mr.data()[204] * Mr.data()[263]) - Mr.data()[111] * Mr.data()
		[172] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[111] * Mr.data()[202] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[111] * Mr.data()
		[217] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[217] * Mr.data()[174] * Mr.data()[248]) - Mr.data()[126] * Mr.data()
		[142] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[126] * Mr.data()[157] * Mr.data()[204] * Mr.data()[263]) - Mr.data()[126] * Mr.data()
		[157] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[172] * Mr.data()[189] * Mr.data()[263]) - Mr.data()[126] * Mr.data()
		[172] * Mr.data()[204] * Mr.data()[248]) - Mr.data()[126] * Mr.data()[172] * Mr.data()[219] * Mr.data()[233]) + Mr.data()[126] * Mr.data()
		[187] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[202] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[126] * Mr.data()
		[202] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[144] * Mr.data()[263]) + Mr.data()[126] * Mr.data()
		[217] * Mr.data()[159] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[174] * Mr.data()[233]) + Mr.data()[141] * Mr.data()
		[127] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[141] * Mr.data()[217] * Mr.data()[129] * Mr.data()[263]) + Mr.data()[156] * Mr.data()
		[112] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[156] * Mr.data()[127] * Mr.data()[204] * Mr.data()[263]) + Mr.data()[156] * Mr.data()
		[127] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[156] * Mr.data()[202] * Mr.data()[129] * Mr.data()[263]) - Mr.data()[156] * Mr.data()
		[217] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[217] * Mr.data()[129] * Mr.data()[248]) + Mr.data()[171] * Mr.data()
		[97] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[204] * Mr.data()[263]) + Mr.data()[171] * Mr.data()
		[112] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[189] * Mr.data()[263]) + Mr.data()[171] * Mr.data()
		[127] * Mr.data()[204] * Mr.data()[248]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[219] * Mr.data()[233]) - Mr.data()[171] * Mr.data()
		[187] * Mr.data()[129] * Mr.data()[263]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[171] * Mr.data()
		[202] * Mr.data()[129] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[99] * Mr.data()[263]) - Mr.data()[171] * Mr.data()
		[217] * Mr.data()[114] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[129] * Mr.data()[233]) - Mr.data()[186] * Mr.data()
		[127] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[186] * Mr.data()[172] * Mr.data()[129] * Mr.data()[263]) - Mr.data()[201] * Mr.data()
		[112] * Mr.data()[174] * Mr.data()[263]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[159] * Mr.data()[263]) - Mr.data()[201] * Mr.data()
		[127] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[201] * Mr.data()[157] * Mr.data()[129] * Mr.data()[263]) + Mr.data()[201] * Mr.data()
		[172] * Mr.data()[114] * Mr.data()[263]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[129] * Mr.data()[248]) - Mr.data()[216] * Mr.data()
		[97] * Mr.data()[174] * Mr.data()[263]) - Mr.data()[216] * Mr.data()[112] * Mr.data()[159] * Mr.data()[263]) - Mr.data()[216] * Mr.data()
		[112] * Mr.data()[174] * Mr.data()[248]) - Mr.data()[216] * Mr.data()[127] * Mr.data()[144] * Mr.data()[263]) - Mr.data()[216] * Mr.data()
		[127] * Mr.data()[159] * Mr.data()[248]) - Mr.data()[216] * Mr.data()[127] * Mr.data()[174] * Mr.data()[233]) + Mr.data()[216] * Mr.data()
		[142] * Mr.data()[129] * Mr.data()[263]) + Mr.data()[216] * Mr.data()[157] * Mr.data()[114] * Mr.data()[263]) + Mr.data()[216] * Mr.data()
		[157] * Mr.data()[129] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[172] * Mr.data()[99] * Mr.data()[263]) + Mr.data()[216] * Mr.data()
		[172] * Mr.data()[114] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[172] * Mr.data()[129] * Mr.data()[233]) + Mr.data()[96] * Mr.data()
		[172] * Mr.data()[218] * Mr.data()[264]) - Mr.data()[96] * Mr.data()[217] * Mr.data()[173] * Mr.data()[264]) + Mr.data()[111] * Mr.data()
		[157] * Mr.data()[218] * Mr.data()[264]) + Mr.data()[111] * Mr.data()[172] * Mr.data()[203] * Mr.data()[264]) + Mr.data()[111] * Mr.data()
		[172] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[111] * Mr.data()[202] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[111] * Mr.data()
		[217] * Mr.data()[158] * Mr.data()[264]) - Mr.data()[111] * Mr.data()[217] * Mr.data()[173] * Mr.data()[249]) + Mr.data()[126] * Mr.data()
		[142] * Mr.data()[218] * Mr.data()[264]) + Mr.data()[126] * Mr.data()[157] * Mr.data()[203] * Mr.data()[264]) + Mr.data()[126] * Mr.data()
		[157] * Mr.data()[218] * Mr.data()[249]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[188] * Mr.data()[264]) + Mr.data()[126] * Mr.data()
		[172] * Mr.data()[203] * Mr.data()[249]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[218] * Mr.data()[234]) - Mr.data()[126] * Mr.data()
		[187] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[126] * Mr.data()[202] * Mr.data()[158] * Mr.data()[264]) - Mr.data()[126] * Mr.data()
		[202] * Mr.data()[173] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[217] * Mr.data()[143] * Mr.data()[264]) - Mr.data()[126] * Mr.data()
		[217] * Mr.data()[158] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[217] * Mr.data()[173] * Mr.data()[234]) - Mr.data()[141] * Mr.data()
		[127] * Mr.data()[218] * Mr.data()[264]) + Mr.data()[141] * Mr.data()[217] * Mr.data()[128] * Mr.data()[264]) - Mr.data()[156] * Mr.data()
		[112] * Mr.data()[218] * Mr.data()[264]) - Mr.data()[156] * Mr.data()[127] * Mr.data()[203] * Mr.data()[264]) - Mr.data()[156] * Mr.data()
		[127] * Mr.data()[218] * Mr.data()[249]) + Mr.data()[156] * Mr.data()[202] * Mr.data()[128] * Mr.data()[264]) + Mr.data()[156] * Mr.data()
		[217] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[156] * Mr.data()[217] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[171] * Mr.data()
		[97] * Mr.data()[218] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[112] * Mr.data()[203] * Mr.data()[264]) - Mr.data()[171] * Mr.data()
		[112] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[127] * Mr.data()[188] * Mr.data()[264]) - Mr.data()[171] * Mr.data()
		[127] * Mr.data()[203] * Mr.data()[249]) - Mr.data()[171] * Mr.data()[127] * Mr.data()[218] * Mr.data()[234]) + Mr.data()[171] * Mr.data()
		[187] * Mr.data()[128] * Mr.data()[264]) + Mr.data()[171] * Mr.data()[202] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[171] * Mr.data()
		[202] * Mr.data()[128] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[217] * Mr.data()[98] * Mr.data()[264]) + Mr.data()[171] * Mr.data()
		[217] * Mr.data()[113] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[217] * Mr.data()[128] * Mr.data()[234]) + Mr.data()[186] * Mr.data()
		[127] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[186] * Mr.data()[172] * Mr.data()[128] * Mr.data()
		[264]) + Mr.data()[201] * Mr.data()[112] * Mr.data()[173] * Mr.data()[264]) + Mr.data()[201] * Mr.data()
		[127] * Mr.data()[158] * Mr.data()[264]) + Mr.data()[201] * Mr.data()[127] * Mr.data()[173] * Mr.data()[249])
		- Mr.data()[201] * Mr.data()[157] * Mr.data()[128] * Mr.data()[264]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[113]
		* Mr.data()[264]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[128] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[97]
		* Mr.data()[173] * Mr.data()[264]) + Mr.data()[216] * Mr.data()[112] * Mr.data()[158] * Mr.data()[264]) + Mr.data()[216] *
		Mr.data()[112] * Mr.data()[173] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[127] * Mr.data()[143] * Mr.data()[264]) + Mr.data()
		[216] * Mr.data()[127] * Mr.data()[158] * Mr.data()[249]) + Mr.data()[216] * Mr.data()[127] * Mr.data()[173] * Mr.data()[234])
		- Mr.data()[216] * Mr.data()[142] * Mr.data()[128] * Mr.data()[264]) - Mr.data()[216] * Mr.data()[157] * Mr.data()[113] * Mr.data()[264])
		- Mr.data()[216] * Mr.data()[157] * Mr.data()[128] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[172] * Mr.data()[98] * Mr.data()[264])
		- Mr.data()[216] * Mr.data()[172] * Mr.data()[113] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[172] * Mr.data()[128] * Mr.data()[234];
	cq[7] =
		(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
		(((((((((((((((((Mr.data()[112] * Mr.data()[218] * Mr.data()[174] * Mr.data()[261] - Mr.data()[112] * Mr.data()[173] * Mr.data()[219]
		* Mr.data()[261]) - Mr.data()[127] * Mr.data()[158] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[127] * Mr.data()[173] * Mr.data()[204] *
		Mr.data()[261]) - Mr.data()[127] * Mr.data()[173] * Mr.data()[219] * Mr.data()[246]) + Mr.data()[127] * Mr.data()[203] * Mr.data()[174] * Mr.data()
		[261]) + Mr.data()[127] * Mr.data()[218] * Mr.data()[159] * Mr.data()[261]) + Mr.data()[127] * Mr.data()[218] * Mr.data()[174] * Mr.data()
		[246]) + Mr.data()[157] * Mr.data()[128] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[157] * Mr.data()[218] * Mr.data()[129] * Mr.data()
		[261]) + Mr.data()[172] * Mr.data()[113] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[172] * Mr.data()[128] * Mr.data()[204] * Mr.data()
		[261]) + Mr.data()[172] * Mr.data()[128] * Mr.data()[219] * Mr.data()[246]) - Mr.data()[172] * Mr.data()[203] * Mr.data()[129] * Mr.data()
		[261]) - Mr.data()[172] * Mr.data()[218] * Mr.data()[114] * Mr.data()[261]) - Mr.data()[172] * Mr.data()[218] * Mr.data()[129] * Mr.data()
		[246]) - Mr.data()[202] * Mr.data()[128] * Mr.data()[174] * Mr.data()[261]) + Mr.data()[202] * Mr.data()[173] * Mr.data()[129] * Mr.data()
		[261]) - Mr.data()[217] * Mr.data()[113] * Mr.data()[174] * Mr.data()[261]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[159] * Mr.data()
		[261]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[174] * Mr.data()[246]) + Mr.data()[217] * Mr.data()[158] * Mr.data()[129] * Mr.data()
		[261]) + Mr.data()[217] * Mr.data()[173] * Mr.data()[114] * Mr.data()[261]) + Mr.data()[217] * Mr.data()[173] * Mr.data()[129] * Mr.data()
		[246]) + Mr.data()[111] * Mr.data()[173] * Mr.data()[219] * Mr.data()[262]) - Mr.data()[111] * Mr.data()[218] * Mr.data()[174] * Mr.data()
		[262]) + Mr.data()[126] * Mr.data()[158] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[204] * Mr.data()
		[262]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[219] * Mr.data()[247]) - Mr.data()[126] * Mr.data()[203] * Mr.data()[174] * Mr.data()
		[262]) - Mr.data()[126] * Mr.data()[218] * Mr.data()[159] * Mr.data()[262]) - Mr.data()[126] * Mr.data()[218] * Mr.data()[174] * Mr.data()
		[247]) - Mr.data()[156] * Mr.data()[128] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[156] * Mr.data()[218] * Mr.data()[129] * Mr.data()
		[262]) - Mr.data()[171] * Mr.data()[113] * Mr.data()[219] * Mr.data()[262]) - Mr.data()[171] * Mr.data()[128] * Mr.data()[204] * Mr.data()
		[262]) - Mr.data()[171] * Mr.data()[128] * Mr.data()[219] * Mr.data()[247]) + Mr.data()[171] * Mr.data()[203] * Mr.data()[129] * Mr.data()
		[262]) + Mr.data()[171] * Mr.data()[218] * Mr.data()[114] * Mr.data()[262]) + Mr.data()[171] * Mr.data()[218] * Mr.data()[129] * Mr.data()
		[247]) + Mr.data()[201] * Mr.data()[128] * Mr.data()[174] * Mr.data()[262]) - Mr.data()[201] * Mr.data()[173] * Mr.data()[129] * Mr.data()
		[262]) + Mr.data()[216] * Mr.data()[113] * Mr.data()[174] * Mr.data()[262]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[159] * Mr.data()
		[262]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[174] * Mr.data()[247]) - Mr.data()[216] * Mr.data()[158] * Mr.data()[129] * Mr.data()
		[262]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[114] * Mr.data()[262]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[129] * Mr.data()
		[247]) - Mr.data()[111] * Mr.data()[172] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[111] * Mr.data()[217] * Mr.data()[174] * Mr.data()
		[263]) - Mr.data()[126] * Mr.data()[157] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[126] * Mr.data()[172] * Mr.data()[204] * Mr.data()
		[263]) - Mr.data()[126] * Mr.data()[172] * Mr.data()[219] * Mr.data()[248]) + Mr.data()[126] * Mr.data()[202] * Mr.data()[174] * Mr.data()
		[263]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[159] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[174] * Mr.data()
		[248]) + Mr.data()[156] * Mr.data()[127] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[156] * Mr.data()[217] * Mr.data()[129] * Mr.data()
		[263]) + Mr.data()[171] * Mr.data()[112] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[204] * Mr.data()
		[263]) + Mr.data()[171] * Mr.data()[127] * Mr.data()[219] * Mr.data()[248]) - Mr.data()[171] * Mr.data()[202] * Mr.data()[129] * Mr.data()
		[263]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[114] * Mr.data()[263]) - Mr.data()[171] * Mr.data()[217] * Mr.data()[129] * Mr.data()
		[248]) - Mr.data()[201] * Mr.data()[127] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[201] * Mr.data()[172] * Mr.data()[129] * Mr.data()
		[263]) - Mr.data()[216] * Mr.data()[112] * Mr.data()[174] * Mr.data()[263]) - Mr.data()[216] * Mr.data()[127] * Mr.data()[159] * Mr.data()
		[263]) - Mr.data()[216] * Mr.data()[127] * Mr.data()[174] * Mr.data()[248]) + Mr.data()[216] * Mr.data()[157] * Mr.data()[129] * Mr.data()
		[263]) + Mr.data()[216] * Mr.data()[172] * Mr.data()[114] * Mr.data()[263]) + Mr.data()[216] * Mr.data()[172] * Mr.data()[129] * Mr.data()
		[248]) + Mr.data()[111] * Mr.data()[172] * Mr.data()[218] * Mr.data()[264]) - Mr.data()[111] * Mr.data()[217] * Mr.data()[173] * Mr.data()
		[264]) + Mr.data()[126] * Mr.data()[157] * Mr.data()[218] * Mr.data()[264]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[203] * Mr.data()
		[264]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[218] * Mr.data()[249]) - Mr.data()[126] * Mr.data()[202] * Mr.data()[173] * Mr.data()
		[264]) - Mr.data()[126] * Mr.data()[217] * Mr.data()[158] * Mr.data()[264]) - Mr.data()[126] * Mr.data()
		[217] * Mr.data()[173] * Mr.data()[249]) - Mr.data()[156] * Mr.data()[127] * Mr.data()[218] * Mr.data()[264])
		+ Mr.data()[156] * Mr.data()[217] * Mr.data()[128] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[112] * Mr.data()[218]
		* Mr.data()[264]) - Mr.data()[171] * Mr.data()[127] * Mr.data()[203] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[127]
		* Mr.data()[218] * Mr.data()[249]) + Mr.data()[171] * Mr.data()[202] * Mr.data()[128] * Mr.data()[264]) + Mr.data()[171] *
		Mr.data()[217] * Mr.data()[113] * Mr.data()[264]) + Mr.data()[171] * Mr.data()[217] * Mr.data()[128] * Mr.data()[249]) + Mr.data()
		[201] * Mr.data()[127] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[201] * Mr.data()[172] * Mr.data()[128] * Mr.data()[264])
		+ Mr.data()[216] * Mr.data()[112] * Mr.data()[173] * Mr.data()[264]) + Mr.data()[216] * Mr.data()[127] * Mr.data()[158] * Mr.data()[264])
		+ Mr.data()[216] * Mr.data()[127] * Mr.data()[173] * Mr.data()[249]) - Mr.data()[216] * Mr.data()[157] * Mr.data()[128] * Mr.data()[264])
		- Mr.data()[216] * Mr.data()[172] * Mr.data()[113] * Mr.data()[264]) - Mr.data()[216] * Mr.data()[172] * Mr.data()[128] * Mr.data()[249];
	cq[8] = ((((((((((((((((((((((Mr.data()[127] * Mr.data()[218] * Mr.data()[174] * Mr.data()[261] - Mr.data()[127] * Mr.data()
		[173] * Mr.data()[219] * Mr.data()[261]) + Mr.data()[172] * Mr.data()[128] * Mr.data()[219] * Mr.data()[261]) - Mr.data()[172] * Mr.data()
		[218] * Mr.data()[129] * Mr.data()[261]) - Mr.data()[217] * Mr.data()[128] * Mr.data()[174] * Mr.data()[261]) + Mr.data()[217] * Mr.data()
		[173] * Mr.data()[129] * Mr.data()[261]) + Mr.data()[126] * Mr.data()[173] * Mr.data()[219] * Mr.data()[262]) - Mr.data()[126] * Mr.data()
		[218] * Mr.data()[174] * Mr.data()[262]) - Mr.data()[171] * Mr.data()[128] * Mr.data()[219] * Mr.data()[262]) + Mr.data()[171] * Mr.data()
		[218] * Mr.data()[129] * Mr.data()[262]) + Mr.data()[216] * Mr.data()[128] * Mr.data()[174] * Mr.data()
		[262]) - Mr.data()[216] * Mr.data()[173] * Mr.data()[129] * Mr.data()[262]) - Mr.data()[126] * Mr.data()
		[172] * Mr.data()[219] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[217] * Mr.data()[174] * Mr.data()[263])
		+ Mr.data()[171] * Mr.data()[127] * Mr.data()[219] * Mr.data()[263]) - Mr.data()[171] * Mr.data()[217] * Mr.data()
		[129] * Mr.data()[263]) - Mr.data()[216] * Mr.data()[127] * Mr.data()[174] * Mr.data()[263]) + Mr.data()[216] *
		Mr.data()[172] * Mr.data()[129] * Mr.data()[263]) + Mr.data()[126] * Mr.data()[172] * Mr.data()[218] * Mr.data()[264]) -
		Mr.data()[126] * Mr.data()[217] * Mr.data()[173] * Mr.data()[264]) - Mr.data()[171] * Mr.data()[127] * Mr.data()[218] * Mr.data()
		[264]) + Mr.data()[171] * Mr.data()[217] * Mr.data()[128] * Mr.data()[264]) + Mr.data()[216] * Mr.data()[127] * Mr.data()
		[173] * Mr.data()[264]) - Mr.data()[216] * Mr.data()[172] * Mr.data()[128] * Mr.data()[264];

	Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> CP(8, 8);
	CP.setZero();
	CP.bottomLeftCorner(7, 7) = Eigen::Matrix<Scalar, 7, 7>::Identity();
	CP.col(7) = -cq.reverse().head(8).transpose() / cq(0);
	Eigen::EigenSolver<Eigen::MatrixXd> es;
	es.compute(CP);


	Eigen::Matrix<std::complex<Scalar>, Eigen::Dynamic, Eigen::Dynamic> qa = es.eigenvalues();
	Eigen::Matrix<Scalar, 4, 4> A;
	Eigen::Matrix<Scalar, 3, 3> Rres;
	Eigen::Matrix<Scalar, 3, 3> Q;
	std::vector<Scalar> q;
	int nsols = 0;

	for (int i = 0; i < qa.size(); i++){
		if (qa(i).imag() == 0){
			q.push_back(qa(i).real());
			A << M2(0, 0)*q[nsols] * q[nsols] + M2(0, 1)*q[nsols] + M2(0, 2), M2(0, 3)*q[nsols] * q[nsols] + M2(0, 4)*q[nsols] + M2(0, 5), M2(0, 6)*q[nsols] * q[nsols] + M2(0, 7)*q[nsols] + M2(0, 8), M2(0, 9)*q[nsols] * q[nsols] + M2(0, 10)*q[nsols] + M2(0, 11),
				M2(1, 0)*q[nsols] * q[nsols] + M2(1, 1)*q[nsols] + M2(1, 2), M2(1, 3)*q[nsols] * q[nsols] + M2(1, 4)*q[nsols] + M2(1, 5), M2(1, 6)*q[nsols] * q[nsols] + M2(1, 7)*q[nsols] + M2(1, 8), M2(1, 9)*q[nsols] * q[nsols] + M2(1, 10)*q[nsols] + M2(1, 11),
				M2(2, 0)*q[nsols] * q[nsols] + M2(2, 1)*q[nsols] + M2(2, 2), M2(2, 3)*q[nsols] * q[nsols] + M2(2, 4)*q[nsols] + M2(2, 5), M2(2, 6)*q[nsols] * q[nsols] + M2(2, 7)*q[nsols] + M2(2, 8), M2(2, 9)*q[nsols] * q[nsols] + M2(2, 10)*q[nsols] + M2(2, 11),
				M2(3, 0)*q[nsols] * q[nsols] + M2(3, 1)*q[nsols] + M2(3, 2), M2(3, 3)*q[nsols] * q[nsols] + M2(3, 4)*q[nsols] + M2(3, 5), M2(3, 6)*q[nsols] * q[nsols] + M2(3, 7)*q[nsols] + M2(3, 8), M2(3, 9)*q[nsols] * q[nsols] + M2(3, 10)*q[nsols] + M2(3, 11);


			Eigen::JacobiSVD<Eigen::Matrix<Scalar, 4, 4>> svd(A, Eigen::ComputeFullU | Eigen::ComputeFullV);
			w[nsols * 3] = svd.matrixV()(0, 3) / svd.matrixV()(3, 3);
			w[nsols * 3 + 1] = svd.matrixV()(1, 3) / svd.matrixV()(3, 3);
			w[nsols * 3 + 2] = svd.matrixV()(2, 3) / svd.matrixV()(3, 3);

			Eigen::Matrix<Scalar, 12, 1> mon;
			mon << q[nsols] * q[nsols] * w[nsols * 3], q[nsols] * w[nsols * 3], w[nsols * 3], q[nsols] * q[nsols] * w[nsols * 3 + 1], q[nsols] * w[nsols * 3 + 1], w[nsols * 3 + 1], q[nsols] * q[nsols] * w[nsols * 3 + 2],
				q[nsols] * w[nsols * 3 + 2], w[nsols * 3 + 2], q[nsols] * q[nsols], q[nsols], 1;

			Scalar k = 1 / (1 + q[nsols] * q[nsols]);
			t[nsols * 3] = -k*Mr.row(3).rightCols(12)*mon;
			t[nsols * 3 + 1] = -k*Mr.row(4).rightCols(12)*mon;
			t[nsols * 3 + 2] = -k*Mr.row(5).rightCols(12)*mon;
			C[nsols * 3] = -k*Mr.row(0).rightCols(12)*mon;
			C[nsols * 3 + 1] = -k*Mr.row(1).rightCols(12)*mon;
			C[nsols * 3 + 2] = -k*Mr.row(2).rightCols(12)*mon;
			Q << 1 - q[nsols] * q[nsols], 0, -2 * q[nsols], 0, 1 + q[nsols] * q[nsols], 0, 2 * q[nsols], 0, 1 - q[nsols] * q[nsols];
			Q = 1 / (1 + q[nsols] * q[nsols])*Q;
			Rres = Rv*Q;
			memcpy(R + nsols * 9, Rres.data(), 9 * sizeof(Scalar));
			nsols++;
		}
	}

	return nsols;


}

#endif